/* Tabela EXTRATOCONS: TABELA DE EXTRATO DO CONSUMIDOR */
/* Descrio: A trigger insere registros na tabela LOGOPERAVND a partir de alteraes na tabela EXTRATOCONS */
/* Objetivo: Gerar um log que vai registrar as alteraes na EXTRATOCONS,
             utilizando a tabela de Logs de Operaes do VND*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'LOG_VND_EXTRATOCONS' AND
                 TYPE   = 'TR' 	               AND
	              U.UID  = O.UID           AND
	              U.NAME = USER)
DROP TRIGGER LOG_VND_EXTRATOCONS
GO


CREATE TRIGGER LOG_VND_EXTRATOCONS
ON EXTRATOCONS
FOR INSERT, UPDATE, DELETE
AS
  DECLARE @V_DSREMOTEADDR VARCHAR(15);
  DECLARE @V_DSREMOTEHOST VARCHAR(15);
  DECLARE @V_DSSERVERRDM  VARCHAR(20);
  DECLARE @V_DSSERVMETHOD VARCHAR(30);
  DECLARE @V_DSREMOTEOPER VARCHAR(12);
  DECLARE @V_DESC         VARCHAR(500);
  DECLARE @V_ITPESQ       VARCHAR(100);
  DECLARE @V_NMOPERADOR   VARCHAR(40);
  DECLARE @V_IDTIPOOPER   VARCHAR(1);

/*VARIVEIS DO CURSOR C_CURSOR*/

  DECLARE @V_ID_COMANDO    VARCHAR(1);
  
  DECLARE @V_NEW_CDCLIENTE        	varchar(21);
  DECLARE @V_NEW_CDCONSUMIDOR        	varchar(21);
  DECLARE @V_NEW_CDFAMILISALD        	varchar(3);
  DECLARE @V_NEW_DTMOVEXTCONS        	datetime;
  DECLARE @V_NEW_NRSEQMOVEXT        	varchar(3);
  DECLARE @V_NEW_CDTIPORECE        	varchar(3);
  DECLARE @V_NEW_CDFILIAL        	varchar(4);
  DECLARE @V_NEW_CDCAIXA        	varchar(3);
  DECLARE @V_NEW_NRSEQVENDA        	varchar(10);
  DECLARE @V_NEW_DSOPEEXTCONS        	varchar(30);
  DECLARE @V_NEW_VRMOVEXTCONS        	decimal(17);
  DECLARE @V_NEW_VRSALDCONEXT        	decimal(17);
  DECLARE @V_NEW_IDTPMOVEXT        	varchar(1);
  DECLARE @V_NEW_IDIMPEXTCONS        	varchar(1);
  DECLARE @V_NEW_NRDEPOSICONS        	varchar(20);
  DECLARE @V_NEW_DTULTATUEXT        	datetime;
  DECLARE @V_NEW_DTABERCAIX        	datetime;
  DECLARE @V_NEW_IDCANZERASALD        	varchar(1);
  DECLARE @V_NEW_NRSEQMOVCAIXA        	varchar(10);
  DECLARE @V_NEW_NRSEQREGCREDVND    	varchar(20);

  DECLARE @V_OLD_CDCLIENTE        	varchar(21);
  DECLARE @V_OLD_CDCONSUMIDOR        	varchar(21);
  DECLARE @V_OLD_CDFAMILISALD        	varchar(3);
  DECLARE @V_OLD_DTMOVEXTCONS        	datetime;
  DECLARE @V_OLD_NRSEQMOVEXT        	varchar(3);
  DECLARE @V_OLD_CDTIPORECE        	varchar(3);
  DECLARE @V_OLD_CDFILIAL        	varchar(4);
  DECLARE @V_OLD_CDCAIXA        	varchar(3);
  DECLARE @V_OLD_NRSEQVENDA        	varchar(10);
  DECLARE @V_OLD_DSOPEEXTCONS        	varchar(30);
  DECLARE @V_OLD_VRMOVEXTCONS        	decimal(17);
  DECLARE @V_OLD_VRSALDCONEXT        	decimal(17);
  DECLARE @V_OLD_IDTPMOVEXT        	varchar(1);
  DECLARE @V_OLD_IDIMPEXTCONS        	varchar(1);
  DECLARE @V_OLD_NRDEPOSICONS        	varchar(20);
  DECLARE @V_OLD_DTULTATUEXT        	datetime;
  DECLARE @V_OLD_DTABERCAIX        	datetime;
  DECLARE @V_OLD_IDCANZERASALD        	varchar(1);
  DECLARE @V_OLD_NRSEQMOVCAIXA        	varchar(10);
  DECLARE @V_OLD_NRSEQREGCREDVND    	varchar(20);

BEGIN
/* IDTIPOOPER - '1' - Incluso, '2' - Alterao, '3' - Excluso*/

   SET @V_DESC   = '';
   SET @V_ITPESQ     = '';
   SET @V_NMOPERADOR = '';
   SET @V_IDTIPOOPER = '';

   EXEC NMUSUARIO @P_NMUSUARIO = @V_NMOPERADOR OUTPUT;
   SET @V_NMOPERADOR = ISNULL(@V_NMOPERADOR, ' ');

   EXEC WEBTUNNING  @P_DSREMOTEADDR = @V_DSREMOTEADDR OUTPUT,
                    @P_DSREMOTEHOST = @V_DSREMOTEHOST OUTPUT,
                    @P_DSSERVERRDM  = @V_DSSERVERRDM OUTPUT,
                    @P_DSSERVMETHOD = @V_DSSERVMETHOD OUTPUT,
                    @P_DSREMOTEOPER = @V_DSREMOTEOPER OUTPUT;

   DECLARE C_CURSOR CURSOR FOR
     SELECT
     'D'   ID_COMANDO,
	   NULL,NULL,
	   NULL,NULL,NULL,NULL,NULL,
	   NULL,NULL,NULL,NULL,NULL,
	   NULL,NULL,NULL,NULL,NULL,
	   NULL,NULL,NULL,NULL,NULL,
           DELETED.CDCLIENTE,
           DELETED.CDCONSUMIDOR,
           DELETED.CDFAMILISALD,
           DELETED.DTMOVEXTCONS,
           DELETED.NRSEQMOVEXT,
           DELETED.CDTIPORECE,
           DELETED.CDFILIAL,
           DELETED.CDCAIXA,
           DELETED.NRSEQVENDA,
           DELETED.DSOPEEXTCONS,
           DELETED.VRMOVEXTCONS,
           DELETED.VRSALDCONEXT,
           DELETED.IDTPMOVEXT,
           DELETED.IDIMPEXTCONS,
           DELETED.NRDEPOSICONS,
           DELETED.DTULTATUEXT,
           DELETED.DTABERCAIX,
           DELETED.IDCANZERASALD,
           DELETED.NRSEQMOVCAIXA,
           DELETED.NRSEQREGCREDVND
     FROM
           DELETED
     WHERE     
           DELETED.CDFILIAL + DELETED.CDCONSUMIDOR + CONVERT(VARCHAR,DELETED.DTMOVEXTCONS) + DELETED.CDFAMILISALD +  DELETED.NRSEQMOVEXT NOT IN (SELECT CDFILIAL + CDCONSUMIDOR + CONVERT(VARCHAR,DTMOVEXTCONS) + CDFAMILISALD + NRSEQMOVEXT FROM INSERTED)
     UNION ALL

     SELECT
     'U'   IDCOMANDO,
           INSERTED.CDCLIENTE,
           INSERTED.CDCONSUMIDOR,
           INSERTED.CDFAMILISALD,
           INSERTED.DTMOVEXTCONS,
           INSERTED.NRSEQMOVEXT,
           INSERTED.CDTIPORECE,
           INSERTED.CDFILIAL,
           INSERTED.CDCAIXA,
           INSERTED.NRSEQVENDA,
           INSERTED.DSOPEEXTCONS,
           INSERTED.VRMOVEXTCONS,
           INSERTED.VRSALDCONEXT,
           INSERTED.IDTPMOVEXT,
           INSERTED.IDIMPEXTCONS,
           INSERTED.NRDEPOSICONS,
           INSERTED.DTULTATUEXT,
           INSERTED.DTABERCAIX,
           INSERTED.IDCANZERASALD,
           INSERTED.NRSEQMOVCAIXA,
           INSERTED.NRSEQREGCREDVND,
           DELETED.CDCLIENTE,
           DELETED.CDCONSUMIDOR,
           DELETED.CDFAMILISALD,
           DELETED.DTMOVEXTCONS,
           DELETED.NRSEQMOVEXT,
           DELETED.CDTIPORECE,
           DELETED.CDFILIAL,
           DELETED.CDCAIXA,
           DELETED.NRSEQVENDA,
           DELETED.DSOPEEXTCONS,
           DELETED.VRMOVEXTCONS,
           DELETED.VRSALDCONEXT,
           DELETED.IDTPMOVEXT,
           DELETED.IDIMPEXTCONS,
           DELETED.NRDEPOSICONS,
           DELETED.DTULTATUEXT,
           DELETED.DTABERCAIX,
           DELETED.IDCANZERASALD,
           DELETED.NRSEQMOVCAIXA,
           DELETED.NRSEQREGCREDVND
     FROM
           INSERTED,
           DELETED
     WHERE     
           INSERTED.CDFILIAL      = DELETED.CDFILIAL     AND
           INSERTED.CDCONSUMIDOR  = DELETED.CDCONSUMIDOR AND
           INSERTED.CDFAMILISALD  = DELETED.CDFAMILISALD AND
           INSERTED.DTMOVEXTCONS  = DELETED.DTMOVEXTCONS  AND
           INSERTED.NRSEQMOVEXT   = DELETED.NRSEQMOVEXT  
     UNION ALL

     SELECT
     'I'   IDCOMANDO,
           INSERTED.CDCLIENTE,
           INSERTED.CDCONSUMIDOR,
           INSERTED.CDFAMILISALD,
           INSERTED.DTMOVEXTCONS,
           INSERTED.NRSEQMOVEXT,
           INSERTED.CDTIPORECE,
           INSERTED.CDFILIAL,
           INSERTED.CDCAIXA,
           INSERTED.NRSEQVENDA,
           INSERTED.DSOPEEXTCONS,
           INSERTED.VRMOVEXTCONS,
           INSERTED.VRSALDCONEXT,
           INSERTED.IDTPMOVEXT,
           INSERTED.IDIMPEXTCONS,
           INSERTED.NRDEPOSICONS,
           INSERTED.DTULTATUEXT,
           INSERTED.DTABERCAIX,
           INSERTED.IDCANZERASALD,
           INSERTED.NRSEQMOVCAIXA,
           INSERTED.NRSEQREGCREDVND,
           NULL,NULL,
	   NULL,NULL,NULL,NULL,NULL,
	   NULL,NULL,NULL,NULL,NULL,
	   NULL,NULL,NULL,NULL,NULL,
	   NULL,NULL,NULL,NULL,NULL

     FROM
           INSERTED
     WHERE     
           INSERTED.CDFILIAL + INSERTED.CDCONSUMIDOR + INSERTED.CDFAMILISALD + INSERTED.NRSEQMOVEXT  NOT IN (SELECT CDFILIAL + CDCONSUMIDOR + CDFAMILISALD + NRSEQMOVEXT FROM DELETED)
	   AND INSERTED.DTMOVEXTCONS NOT IN (SELECT DTMOVEXTCONS FROM DELETED)

     OPEN C_CURSOR;
     FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
				   @V_NEW_CDCLIENTE,@V_NEW_CDCONSUMIDOR,@V_NEW_CDFAMILISALD,@V_NEW_DTMOVEXTCONS,
				   @V_NEW_NRSEQMOVEXT,@V_NEW_CDTIPORECE,@V_NEW_CDFILIAL,@V_NEW_CDCAIXA,
				   @V_NEW_NRSEQVENDA,@V_NEW_DSOPEEXTCONS,@V_NEW_VRMOVEXTCONS,@V_NEW_VRSALDCONEXT,
				   @V_NEW_IDTPMOVEXT,@V_NEW_IDIMPEXTCONS,@V_NEW_NRDEPOSICONS,@V_NEW_DTULTATUEXT,
				   @V_NEW_DTABERCAIX,@V_NEW_IDCANZERASALD,
				   @V_NEW_NRSEQMOVCAIXA,@V_NEW_NRSEQREGCREDVND,
				   @V_OLD_CDCLIENTE,@V_OLD_CDCONSUMIDOR,@V_OLD_CDFAMILISALD,@V_OLD_DTMOVEXTCONS,
				   @V_OLD_NRSEQMOVEXT,@V_OLD_CDTIPORECE,@V_OLD_CDFILIAL,@V_OLD_CDCAIXA,
				   @V_OLD_NRSEQVENDA,@V_OLD_DSOPEEXTCONS,@V_OLD_VRMOVEXTCONS,@V_OLD_VRSALDCONEXT,
				   @V_OLD_IDTPMOVEXT,@V_OLD_IDIMPEXTCONS,@V_OLD_NRDEPOSICONS,@V_OLD_DTULTATUEXT,
				   @V_OLD_DTABERCAIX,@V_OLD_IDCANZERASALD,
				   @V_OLD_NRSEQMOVCAIXA,@V_OLD_NRSEQREGCREDVND

    WHILE (@@FETCH_STATUS = 0) BEGIN
    
       IF @V_ID_COMANDO= 'U' /*UPDATE*/ BEGIN
		IF ISNULL(@V_NEW_CDCLIENTE,'NULL') <> ISNULL(@V_OLD_CDCLIENTE,'NULL') BEGIN
			SET @V_DESC  = 'Cliente ' + ISNULL(@V_NEW_CDCLIENTE,'');
		END;
		IF ISNULL(@V_NEW_CDCONSUMIDOR,'NULL') <> ISNULL(@V_OLD_CDCONSUMIDOR,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Cd Cons ' + ISNULL(@V_NEW_CDCONSUMIDOR,'');
		END;
		IF ISNULL(@V_NEW_CDFAMILISALD,'NULL') <> ISNULL(@V_OLD_CDFAMILISALD,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  CDFAMILISALD ' + ISNULL(@V_NEW_CDFAMILISALD,'');
		END;
		IF ISNULL(CONVERT(VARCHAR,@V_NEW_DTMOVEXTCONS),'NULL') <> ISNULL(CONVERT(VARCHAR,@V_OLD_DTMOVEXTCONS),'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Dt Mov Ext ' + ISNULL(CONVERT(VARCHAR,@V_NEW_DTMOVEXTCONS),'');
		END;
		IF ISNULL(@V_NEW_NRSEQMOVEXT,'NULL') <> ISNULL(@V_OLD_NRSEQMOVEXT,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  NRSEQMOVEXT ' + ISNULL(@V_NEW_NRSEQMOVEXT,'');
		END;
		IF ISNULL(@V_NEW_CDTIPORECE,'NULL') <> ISNULL(@V_OLD_CDTIPORECE,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Tp Rece ' + ISNULL(@V_NEW_CDTIPORECE,'');
		END;
		IF ISNULL(@V_NEW_CDFILIAL,'NULL') <> ISNULL(@V_OLD_CDFILIAL,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Filial ' + ISNULL(@V_NEW_CDFILIAL,'');
		END;
		IF ISNULL(@V_NEW_CDCAIXA,'NULL') <> ISNULL(@V_OLD_CDCAIXA,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Caixa ' + ISNULL(@V_NEW_CDCAIXA,'');
		END;
		IF ISNULL(@V_NEW_NRSEQVENDA,'NULL') <> ISNULL(@V_OLD_NRSEQVENDA,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Nr Seq Venda ' + ISNULL(@V_NEW_NRSEQVENDA,'');
		END;
		IF ISNULL(@V_NEW_DSOPEEXTCONS,'NULL') <> ISNULL(@V_OLD_DSOPEEXTCONS,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  DSOPEEXTCONS ' + ISNULL(@V_NEW_DSOPEEXTCONS,'');
		END;
		IF ISNULL(CONVERT(VARCHAR,@V_NEW_VRMOVEXTCONS),'NULL') <> ISNULL(CONVERT(VARCHAR,@V_OLD_VRMOVEXTCONS),'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Vr Mov Ext ' + ISNULL(CONVERT(VARCHAR,@V_NEW_VRMOVEXTCONS),'');
		END;
		IF ISNULL(CONVERT(VARCHAR,@V_NEW_VRSALDCONEXT),'NULL') <> ISNULL(CONVERT(VARCHAR,@V_OLD_VRSALDCONEXT),'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Vr Saldo Cons ' + ISNULL(CONVERT(VARCHAR,@V_NEW_VRSALDCONEXT),'');
		END;
		IF ISNULL(@V_NEW_IDTPMOVEXT,'NULL') <> ISNULL(@V_OLD_IDTPMOVEXT,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Tp Mov ' + ISNULL(@V_NEW_IDTPMOVEXT,'');
		END;
		IF ISNULL(@V_NEW_IDIMPEXTCONS,'NULL') <> ISNULL(@V_OLD_IDIMPEXTCONS,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Id Mov Exp ' + ISNULL(@V_NEW_IDIMPEXTCONS,'');
		END;
		IF ISNULL(@V_NEW_NRDEPOSICONS,'NULL') <> ISNULL(@V_OLD_NRDEPOSICONS,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  NRDEPOSICONS ' + ISNULL(@V_NEW_NRDEPOSICONS,'');
		END;
		IF ISNULL(CONVERT(VARCHAR,@V_NEW_DTULTATUEXT),'NULL') <> ISNULL(CONVERT(VARCHAR,@V_OLD_DTULTATUEXT),'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Dt Ult Atu ' + ISNULL(CONVERT(VARCHAR,@V_NEW_DTULTATUEXT),'');
		END;
		IF ISNULL(CONVERT(VARCHAR,@V_NEW_DTABERCAIX),'NULL') <> ISNULL(CONVERT(VARCHAR,@V_OLD_DTABERCAIX),'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Aber Caixa ' + ISNULL(CONVERT(VARCHAR,@V_NEW_DTABERCAIX),'');
		END;
		IF ISNULL(@V_NEW_IDCANZERASALD,'NULL') <> ISNULL(@V_OLD_IDCANZERASALD,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  IDCANZERASALD ' + ISNULL(@V_NEW_IDCANZERASALD,'');
		END;
		IF ISNULL(@V_NEW_NRSEQMOVCAIXA,'NULL') <> ISNULL(@V_OLD_NRSEQMOVCAIXA,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  NRSEQMOVCAIXA ' + ISNULL(@V_NEW_NRSEQMOVCAIXA,'');
		END;
		IF ISNULL(@V_NEW_NRSEQREGCREDVND,'NULL') <> ISNULL(@V_OLD_NRSEQREGCREDVND,'NULL') BEGIN
			SET @V_DESC  = ISNULL(@V_DESC,'') + '  NRSEQREGCREDVND ' + ISNULL(@V_NEW_NRSEQREGCREDVND,'');
		END;
        SET @V_IDTIPOOPER = '2';
       END;
       IF @V_ID_COMANDO= 'I' /*INSERO*/ BEGIN
          SET @V_DESC  = 'Cliente '           + ISNULL(@V_NEW_CDCLIENTE,'')    +  ' '  + 
                  'Cd Cons '           + ISNULL(@V_NEW_CDCONSUMIDOR,''    )    +  ' '  + 
                  'CDFAMILISALD '      + ISNULL(@V_NEW_CDFAMILISALD,''    )    +  ' '  + 
                  'Dt Mov Ext '        + ISNULL(CONVERT(VARCHAR,@V_NEW_DTMOVEXTCONS),''    )    +  ' '  + 
                  'NRSEQMOVEXT '       + ISNULL(@V_NEW_NRSEQMOVEXT,''     )    +  ' '  + 
                  'Tp Rece '           + ISNULL(@V_NEW_CDTIPORECE,''      )    +  ' '  + 
                  'Filial '            + ISNULL(@V_NEW_CDFILIAL,''        )    +  ' '  + 
                  'Caixa '             + ISNULL(@V_NEW_CDCAIXA,''         )    +  ' '  + 
                  'Nr Seq Venda '      + ISNULL(@V_NEW_NRSEQVENDA,''      )    +  ' '  + 
                  'DSOPEEXTCONS '      + ISNULL(@V_NEW_DSOPEEXTCONS,''    )    +  ' '  + 
                  'Vr Mov Ext '        + ISNULL(CONVERT(VARCHAR,@V_NEW_VRMOVEXTCONS),''    )    +  ' '  + 
                  'Vr Saldo Cons '     + ISNULL(CONVERT(VARCHAR,@V_NEW_VRSALDCONEXT),''    )    +  ' '  + 
                  'Tp Mov '            + ISNULL(@V_NEW_IDTPMOVEXT,''      )    +  ' '  + 
                  'Id Mov Exp '        + ISNULL(@V_NEW_IDIMPEXTCONS,''    )    +  ' '  + 
                  'NRDEPOSICONS '      + ISNULL(@V_NEW_NRDEPOSICONS,''    )    +  ' '  + 
                  'Dt Ult Atu '        + ISNULL(CONVERT(VARCHAR,@V_NEW_DTULTATUEXT),''     )    +  ' '  + 
                  'Aber Caixa '        + ISNULL(CONVERT(VARCHAR,@V_NEW_DTABERCAIX),''      )    +  ' '  + 
                  'IDCANZERASALD '     + ISNULL(@V_NEW_IDCANZERASALD,''   )    +  ' '  + 
                  'NRSEQMOVCAIXA '     + ISNULL(@V_NEW_NRSEQMOVCAIXA,''   )    +  ' '  +
		  'NRSEQREGCREDVND '   + ISNULL(@V_NEW_NRSEQREGCREDVND,'' );
          SET @V_IDTIPOOPER = '1';
       END;
       IF @V_ID_COMANDO= 'D' /*DELEO*/  BEGIN
          SET @V_DESC  = 'Cliente '           + ISNULL(@V_OLD_CDCLIENTE,'')    +  ' '  + 
                  'Cd Cons '           + ISNULL(@V_OLD_CDCONSUMIDOR,''    )    +  ' '  + 
                  'CDFAMILISALD '      + ISNULL(@V_OLD_CDFAMILISALD,''    )    +  ' '  + 
                  'Dt Mov Ext '        + ISNULL(CONVERT(VARCHAR,@V_OLD_DTMOVEXTCONS),''    )    +  ' '  + 
                  'NRSEQMOVEXT '       + ISNULL(@V_OLD_NRSEQMOVEXT,''     )    +  ' '  + 
                  'Tp Rece '           + ISNULL(@V_OLD_CDTIPORECE,''      )    +  ' '  + 
                  'Filial '            + ISNULL(@V_OLD_CDFILIAL,''        )    +  ' '  + 
                  'Caixa '             + ISNULL(@V_OLD_CDCAIXA,''         )    +  ' '  + 
                  'Nr Seq Venda '      + ISNULL(@V_OLD_NRSEQVENDA,''      )    +  ' '  + 
                  'DSOPEEXTCONS '      + ISNULL(@V_OLD_DSOPEEXTCONS,''    )    +  ' '  + 
                  'Vr Mov Ext '        + ISNULL(CONVERT(VARCHAR,@V_OLD_VRMOVEXTCONS),''    )    +  ' '  + 
                  'Vr Saldo Cons '     + ISNULL(CONVERT(VARCHAR,@V_OLD_VRSALDCONEXT),''    )    +  ' '  + 
                  'Tp Mov '            + ISNULL(@V_OLD_IDTPMOVEXT,''      )    +  ' '  + 
                  'Id Mov Exp '        + ISNULL(@V_OLD_IDIMPEXTCONS,''    )    +  ' '  + 
                  'NRDEPOSICONS '      + ISNULL(@V_OLD_NRDEPOSICONS,''    )    +  ' '  + 
                  'Dt Ult Atu '        + ISNULL(CONVERT(VARCHAR,@V_OLD_DTULTATUEXT),''     )    +  ' '  + 
                  'Aber Caixa '        + ISNULL(CONVERT(VARCHAR,@V_OLD_DTABERCAIX),''      )    +  ' '  + 
                  'IDCANZERASALD '     + ISNULL(@V_OLD_IDCANZERASALD,''   )    +  ' '  + 
                  'NRSEQMOVCAIXA '     + ISNULL(@V_OLD_NRSEQMOVCAIXA,''   )    +  ' '  +
		  'NRSEQREGCREDVND '   + ISNULL(@V_OLD_NRSEQREGCREDVND,'' );
          SET @V_IDTIPOOPER = '3';
       END;

       IF  (@V_IDTIPOOPER <> '') BEGIN
          IF @V_DESC IS NOT NULL BEGIN
             SET @V_ITPESQ =  ISNULL( @V_NEW_CDFILIAL + @V_NEW_CDCONSUMIDOR + @V_NEW_CDFAMILISALD + CONVERT(VARCHAR,@V_NEW_DTMOVEXTCONS) + @V_NEW_NRSEQMOVEXT , @V_OLD_CDFILIAL + @V_OLD_CDCONSUMIDOR + @V_OLD_CDFAMILISALD + CONVERT(VARCHAR,@V_OLD_DTMOVEXTCONS) + @V_OLD_NRSEQMOVEXT );
             SET @V_DESC = SUBSTRING(@V_DESC, 1, 300);
             INSERT INTO LOGOPERAVND
                    (NMTABELAVND, DTOPERACAOVND, NMRESPOPERVND, IDTIPOOPERVND, DSOPERACAOVND,
                     CDPESQITEMVND, DSRDMUSUOPERVND, DSENDUSUOPERVND, DSNMUSUOPERVND, DSMETUSUOPERVND,
                     CDORESPOPERVND, CDFILLOGOPERVND)
             VALUES ('EXTRATOCONS',GETDATE(), ISNULL(@V_NMOPERADOR,' '), @V_IDTIPOOPER, @V_DESC, @V_ITPESQ,
                     @V_DSSERVERRDM, @V_DSREMOTEADDR, @V_DSREMOTEHOST, @V_DSSERVMETHOD, @V_DSREMOTEOPER,
                     ISNULL(@V_NEW_CDFILIAL,@V_OLD_CDFILIAL));
          END;
       END;
       FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
				     @V_NEW_CDCLIENTE,@V_NEW_CDCONSUMIDOR,@V_NEW_CDFAMILISALD,@V_NEW_DTMOVEXTCONS,
				     @V_NEW_NRSEQMOVEXT,@V_NEW_CDTIPORECE,@V_NEW_CDFILIAL,@V_NEW_CDCAIXA,
				     @V_NEW_NRSEQVENDA,@V_NEW_DSOPEEXTCONS,@V_NEW_VRMOVEXTCONS,@V_NEW_VRSALDCONEXT,
				     @V_NEW_IDTPMOVEXT,@V_NEW_IDIMPEXTCONS,@V_NEW_NRDEPOSICONS,@V_NEW_DTULTATUEXT,
				     @V_NEW_DTABERCAIX,@V_NEW_IDCANZERASALD,
				     @V_NEW_NRSEQMOVCAIXA,@V_NEW_NRSEQREGCREDVND,
				     @V_OLD_CDCLIENTE,@V_OLD_CDCONSUMIDOR,@V_OLD_CDFAMILISALD,@V_OLD_DTMOVEXTCONS,
				     @V_OLD_NRSEQMOVEXT,@V_OLD_CDTIPORECE,@V_OLD_CDFILIAL,@V_OLD_CDCAIXA,
				     @V_OLD_NRSEQVENDA,@V_OLD_DSOPEEXTCONS,@V_OLD_VRMOVEXTCONS,@V_OLD_VRSALDCONEXT,
				     @V_OLD_IDTPMOVEXT,@V_OLD_IDIMPEXTCONS,@V_OLD_NRDEPOSICONS,@V_OLD_DTULTATUEXT,
				     @V_OLD_DTABERCAIX,@V_OLD_IDCANZERASALD,
				     @V_OLD_NRSEQMOVCAIXA,@V_OLD_NRSEQREGCREDVND
    SET @V_DESC   = '';
    END;
    CLOSE      C_CURSOR;
    DEALLOCATE C_CURSOR;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_VND_EXTRATOCONS','5.20.001';
GO 