/*
 Tecnisa - Tecnologia em Informtica

 Nome: Atualiza_Saldo_Bancario

 Descrio:
 Procedimento para evoluo/atualizao dos saldos da conta corrente.

 Criao:
 24/03/2005 - Jenilson Ferreira

 Chamada para criao
 @C:\Win_V4\Sql\End_Conv\SqlServer\1016_FINSTPO_ATUALIZA_SALDO_BANCARIO.SQL

 */

IF EXISTS (SELECT
             *
          FROM SYSOBJECTS O, SYSUSERS U
          WHERE
             O.NAME = 'ATUALIZA_SALDO_BANCARIO' AND
             TYPE = 'P' 		        AND
             U.UID = O.UID                      AND
             U.NAME = USER)

DROP PROCEDURE ATUALIZA_SALDO_BANCARIO
GO

CREATE PROCEDURE ATUALIZA_SALDO_BANCARIO
    @P_CDREDUCONT  VARCHAR(03),
    @P_DTSALDO     DATETIME,
    @P_VRSDOCCORR  FLOAT,
    @P_IDATUALIZA  VARCHAR(01)
AS
   DECLARE @V_LOOP             INTEGER;
   DECLARE @V_DTMOVIMENTO      DATETIME;
   DECLARE @V_VRMOVIMENTO      FLOAT;
   DECLARE @V_VRSALDOIMPL      FLOAT;
   DECLARE @V_SALDOANT         FLOAT;

   DECLARE @C_SALDO_DTMOVBANC  DATETIME;
   DECLARE @C_SALDO_VRSDOMOV   FLOAT;
   DECLARE @C_SALDO_VRSDOIMPLA FLOAT;
   DECLARE @C_SALDO_IDEXISTS   INTEGER;
   DECLARE @C_SALDO_DTSDOCCORR DATETIME;
   DECLARE @C_SALDO_VRSDOCCORR FLOAT;
BEGIN

   IF (@P_IDATUALIZA = '0') BEGIN /* REALIZA A EVOLUO DO SALDO DA CONTA CORRENTE*/
      SET @V_LOOP        = 0;
      SET @V_VRMOVIMENTO = 0;
      SET @V_VRSALDOIMPL = 0;
      SET @V_DTMOVIMENTO = NULL;

      SELECT @V_DTMOVIMENTO = MAX(DTSDOCCORR)
      FROM
         SDOCCORR
      WHERE
         CDREDUCONT = @P_CDREDUCONT  AND
         DTSDOCCORR = (SELECT MAX(DTSDOCCORR)
                       FROM SDOCCORR
                       WHERE CDREDUCONT =  @P_CDREDUCONT AND
                             DTSDOCCORR <= @P_DTSALDO    AND
                             NOT VRSDOIMPLA IS NULL);

      IF (@V_DTMOVIMENTO IS NULL) BEGIN
         SELECT @V_DTMOVIMENTO = MAX(DTSDOCCORR)
         FROM
            SDOCCORR
         WHERE
            CDREDUCONT = @P_CDREDUCONT  AND
            DTSDOCCORR = (SELECT MAX(DTSDOCCORR)
                          FROM SDOCCORR
                          WHERE CDREDUCONT =  @P_CDREDUCONT AND
                                DTSDOCCORR <= @P_DTSALDO);
      END;

      IF (@V_DTMOVIMENTO IS NULL) BEGIN
         SELECT @V_DTMOVIMENTO = MIN(DTSDOCCORR)
         FROM
            SDOCCORR
         WHERE
            CDREDUCONT = @P_CDREDUCONT;
      END;

      DECLARE C_SALDO CURSOR FOR
      SELECT A.DTMOVBANC,
             SUM(A.VRMOVBANC)  AS VRSDOMOV,
             SUM(IDEXISTS)     AS IDEXISTS,
             SUM(A.VRSDOIMPLA) AS VRSDOIMPLA
      FROM
         (SELECT
             DTMOVBANC,
             VRMOVBANC,
             0           AS IDEXISTS,
             0           AS VRSDOIMPLA
          FROM
             MOVBANCARIO
          WHERE
             (CDREDUCONT = @P_CDREDUCONT)  AND
             (DTMOVBANC >= @V_DTMOVIMENTO) AND
             (IDMOVBANC  = 'C')
          UNION ALL
          SELECT
             DTMOVBANC,
             VRMOVBANC * -1,
             0           AS IDEXISTS,
             0           AS VRSDOIMPLA
          FROM
             MOVBANCARIO
          WHERE
             (CDREDUCONT = @P_CDREDUCONT)  AND
             (DTMOVBANC >= @V_DTMOVIMENTO) AND
             (IDMOVBANC  = 'D')
          UNION ALL
          SELECT
             DTSDOCCORR  AS DTMOVBANC,
             0           AS VRMOVBANC,
             1           AS IDEXISTS,
             VRSDOIMPLA
          FROM
             SDOCCORR
          WHERE
             (CDREDUCONT =  @P_CDREDUCONT)  AND
             (DTSDOCCORR >= @V_DTMOVIMENTO) AND
             (NOT VRSDOIMPLA IS NULL)) A
      GROUP BY
         A.DTMOVBANC
      ORDER BY
         A.DTMOVBANC;

      OPEN C_SALDO;

      FETCH NEXT FROM C_SALDO INTO @C_SALDO_DTMOVBANC,
                                   @C_SALDO_VRSDOMOV,
                                   @C_SALDO_IDEXISTS,
                                   @C_SALDO_VRSDOIMPLA;

      WHILE (@@FETCH_STATUS = 0) BEGIN

         IF (@V_LOOP = 0) BEGIN
            DELETE FROM SDOCCORR
            WHERE
               (CDREDUCONT =  @P_CDREDUCONT) AND
               (DTSDOCCORR >= @V_DTMOVIMENTO);
            SET @V_LOOP = 1;
         END;

         /* REALIZA A EVOLUCAO DO SALDO DA CONTA CORRENTE  */
         IF (@C_SALDO_IDEXISTS > 0) BEGIN
            SET @V_VRMOVIMENTO = ROUND(@C_SALDO_VRSDOIMPLA, 2);
            SET @V_VRSALDOIMPL = @V_VRMOVIMENTO;
         END
         ELSE BEGIN
            SET @V_VRMOVIMENTO = ROUND(@V_VRMOVIMENTO + @C_SALDO_VRSDOMOV, 2);
            SET @V_VRSALDOIMPL = NULL;
         END;

         INSERT INTO SDOCCORR
            (CDREDUCONT,
             DTSDOCCORR,
             VRSDOCCORR,
             VRSDOIMPLA)
         VALUES
            (@P_CDREDUCONT,
             @C_SALDO_DTMOVBANC,
             @V_VRMOVIMENTO,
             @V_VRSALDOIMPL);

         FETCH NEXT FROM C_SALDO INTO @C_SALDO_DTMOVBANC,
                                      @C_SALDO_VRSDOMOV,
                                      @C_SALDO_IDEXISTS,
                                      @C_SALDO_VRSDOIMPLA;
      END;
      CLOSE C_SALDO;
      DEALLOCATE C_SALDO;
   END;

   IF (@P_IDATUALIZA = '1') BEGIN /* REALIZA A ATUALIZAO DO SALDO DA CONTA CORRENTE*/
      SET @V_LOOP        = 0;
      SET @V_VRMOVIMENTO = ROUND(@P_VRSDOCCORR, 2);
      SET @V_SALDOANT    = 0;

      /* RETORNA O SALDO DO DIA ANTERIOR */
      SELECT @V_SALDOANT = ISNULL(SUM(VRSDOCCORR), 0)
      FROM
         SDOCCORR
      WHERE
         CDREDUCONT = @P_CDREDUCONT  AND
         DTSDOCCORR = (SELECT MAX(DTSDOCCORR)
                       FROM SDOCCORR
                       WHERE CDREDUCONT =  @P_CDREDUCONT AND
                             DTSDOCCORR <= @P_DTSALDO -1);

      DECLARE C_SALDO CURSOR FOR
      SELECT
         DTSDOCCORR,
         VRSDOCCORR,
         VRSDOIMPLA
      FROM
         SDOCCORR
      WHERE
         (CDREDUCONT =  @P_CDREDUCONT) AND
         (DTSDOCCORR >= @P_DTSALDO)
      ORDER BY
         DTSDOCCORR;

      OPEN C_SALDO;

      FETCH NEXT FROM C_SALDO INTO @C_SALDO_DTSDOCCORR,
                                   @C_SALDO_VRSDOCCORR,
                                   @C_SALDO_VRSDOIMPLA;

      WHILE (@@FETCH_STATUS = 0) BEGIN

          IF (@P_DTSALDO < @C_SALDO_DTSDOCCORR) AND (@V_LOOP = 0) BEGIN
             /* INSERE O NOVO SALDO */
             INSERT INTO SDOCCORR
                (CDREDUCONT,
                 DTSDOCCORR,
                 VRSDOCCORR,
                 VRSDOIMPLA)
             VALUES
                (@P_CDREDUCONT,
                 @P_DTSALDO,
                 ROUND(@V_SALDOANT + @V_VRMOVIMENTO, 2),
                 NULL);
          END;
          SET @V_LOOP = 1;

          IF (NOT @C_SALDO_VRSDOIMPLA IS NULL) BEGIN
             BREAK;
          END;

          /* ALTERA O SALDO ATUAL  */
          UPDATE SDOCCORR
          SET VRSDOCCORR = ROUND(VRSDOCCORR + @V_VRMOVIMENTO, 2)
          WHERE
             CDREDUCONT = @P_CDREDUCONT  AND
             DTSDOCCORR = @C_SALDO_DTSDOCCORR;

         FETCH NEXT FROM C_SALDO INTO @C_SALDO_DTSDOCCORR,
                                      @C_SALDO_VRSDOCCORR,
                                      @C_SALDO_VRSDOIMPLA;
      END;
      CLOSE C_SALDO;
      DEALLOCATE C_SALDO;

      IF (@V_LOOP = 0) BEGIN
         /* INSERE O NOVO SALDO */
         INSERT INTO SDOCCORR
            (CDREDUCONT,
             DTSDOCCORR,
             VRSDOCCORR,
             VRSDOIMPLA)
         VALUES
            (@P_CDREDUCONT,
             @P_DTSALDO,
             ROUND(@V_SALDOANT + @V_VRMOVIMENTO, 2),
             NULL);
      END;
   END;
END;
GO

