function Cmp07500JustificativaAfsController(ScreenService, General, Utilities, templateManager, MessageService) {
	function beforeGenerateReport(data) {
	    const filterRow = templateManager.container.getWidget('justificativaAfs').appliedFilter.FILTER_ROW;
	    
	    data.metadata.filter = [
	        {
	            label: 'Unidade de Destino',
	            value: filterRow.CDFILDEST.join(', ')
	        },
	        {
	            label: 'Produto Inicial',
	            value: filterRow.CDARVPRODINI +" - "+ filterRow.NMPRODUTOINI
	        },
	        {
	            label: 'Produto Final',
	            value: filterRow.CDARVPRODFIM +" - "+ filterRow.NMPRODUTOFIM
	        },
	        {
	            label: 'Período de Entrega',
	            value: filterRow.INTERVALO_DATA.start +" a "+ filterRow.INTERVALO_DATA.end 
	        }
	   ];
	}
	
	function concatArrayForParams(value, defaultValue = 'T') {
        if (!Util.isEmptyOrBlank(value)) {
            return Array.isArray(value) ? value.join('_') : value;
        }
        return defaultValue;
    }
    
    function validaProduto(prodInicial, prodFinal) {
        
        if(prodInicial && prodFinal){
            if (!General.comparaPratoProduto(prodInicial, prodFinal, getLocalVar('CDPICTPROD'))) {
                MessageService.showMessageByCode("PRODUTO_INICIAL_MENOR_IGUAL_FINAL");
                return false;
            }
        }
        return true;
    }
	
	this.atualizaFiltroUnidadeDestino = function (widget) {
		var fieldUnidadeDestino = widget.getField('CDFILDEST'),
		currentRow = widget.currentRow;
		
		fieldUnidadeDestino.dataSourceFilter = [
		    {
                "name": "NRORG",
                "operator": "=",
                "value": getLocalVar('NRORG')
            },
            {
                "name": "CDOPERADOR",
                "operator": "=",
                "value": getLocalVar('CDOPERADOR')
            },
            {
                "name": "CDGRUPFILI",
                "operator": "=",
                "value": currentRow.CDGRUPFILI ? currentRow.CDGRUPFILI : 'T'
            }
		];
        
		fieldUnidadeDestino.clearValue();
		fieldUnidadeDestino.reload();
	};
	
	this.setInitValues = function(widget) {
		const filialField = widget.getField("CDFILDEST");
		General.callRestEngine("cmp#/getCdFilCentCmp", "Row", {}).then(function(response) {
	        const filterRow = {
	    	    INTERVALO_DATA : {
	                'formattedStart' : moment().format('DD/MM/YYYY'),
	                'start'          : moment().format('DD/MM/YYYY'),
	                'formattedEnd'   : moment().format('DD/MM/YYYY'),
	                'end'            : moment().format('DD/MM/YYYY')
	            },
	            CDFILDEST: [ getLocalVar("CDFILIAL") ],
	            NMFILIAL: [ getLocalVar("NMFILIAL") ],
	            IDBAIXAAF   : [ "0", "1", "2", "3", "4", "5" ],
	            NMIDBAIXAAF : [ "Em Aberto", "Baixa Parcial", "Baixa Total", "Baixa Manual", "Encerrada", "Cancelada" ],
	            IDTIPOLAN   : "T"
	        };
	        
	        if(response.dataset.data.CDFILCENTCMP == response.dataset.data.CDFILIAL) {
                var NMFILCENTCMP = response.dataset.data.NMFILCENTCMP;
                var CDFILCENTCMP = response.dataset.data.CDFILCENTCMP;
                filterRow.CDFILDEST = [ CDFILCENTCMP ];
                filterRow.NMFILIAL = [ NMFILCENTCMP ];
                filialField.readOnly = false;
                filialField.reload().then(function(success) {
                    let verificador = 0;
    	           success.dataset.filialgrupfili.forEach(function(filial) {
    	               if(filial.CDFILIAL == filterRow.CDFILDEST[0]) {
    	                   verificador++;
    	               }
    	           });
    	           if(verificador == 0) {
    	               delete filterRow.CDFILDEST;
    	               delete filterRow.NMFILIAL;
    	               filialField.reload();
    	           }
                });
            } else {
                filialField.readOnly = true;
                filialField.reload().then(function(success) {
    	           if(filialField.readOnly == true) {
    	               let verificador = 0;
    	               success.dataset.filialgrupfili.forEach(function(filial) {
    	                   if(filial.CDFILIAL == filterRow.CDFILDEST[0]) {
    	                       verificador++;
    	                   }
    	               });
    	               if(verificador == 0) {
    	                   filialField.validations.required = true;
    	                   MessageService.showMessageByCode("FILIAL_SEM_REGIAO", null, { type: 'ERROR' });
    	                   delete filterRow.CDFILDEST;
    	                   delete filterRow.NMFILIAL;
    	                   filialField.reload();
    	               } else {
    	                   delete filialField.validations.required;
    	                   filialField.reload();
    	               }
    	           }
    	       });
            }
	       
			Utilities.startFilter(widget, filterRow);
			widget.beforeGenerateReport = beforeGenerateReport;
		}, function(error) {
            MessageService.showMessageByCode(error.data ? 'cmp#' + error.data.error : 'Timeout', null, { type: 'ERROR' });
        });
    };
    
    this.skipFilterZeedhi = function(args) {
    	args.e.preference.CUSTOM_FILTER_ROW = {};
    };
    
    this.setDataSourceFilterJustificativaAf = function (args) {
    	const row                   = concatenaEscolhas(args.e.preference.FILTER_ROW);
        const widget                = templateManager.container.getWidget('justificativaAfs');
        const filterPopupCurrentRow = widget.appliedFilter.FILTER_ROW;
        
	widget.dataSourceFilter = [
	        {
				"name": "P_CDFILDESMOV",
				"operator": "=",
				"value": concatArrayForParams(row.CDFILDEST)
			},
			    			{
				"name": "P_IDBAIXAAF",
				"operator": "=",
				"value": row.P_IDBAIXAAF
			},
            {
				"name": "P_IDTIPOLAN",
				"operator": "=",
				"value": row.IDTIPOLAN
			},
			{
				"name": "P_DTINI",
				"operator": "=",
				"value": row.INTERVALO_DATA.start
			},
			{
				"name": "P_DTFIM",
				"operator": "=",
				"value": row.INTERVALO_DATA.end
			},
			{
				"name": "P_PRODINI",
				"operator": "=",
				"value": row.CDARVPRODINI
			},
			{
				"name": "P_PRODFIN",
				"operator": "=",
				"value": General.fill(row.CDARVPRODFIM, 20, true, 'Z')
			},
			{
				"name": "P_CDOPERADOR",
				"operator": "=",
				"value": getLocalVar("CDOPERADOR")
			}
		];
		
    	widget.reload();
    	widget.activate();
    };

    this.productValidations = function(field) {
        const row         = field.widget.currentRow;
        const prodInicial = row.CDARVPRODINI;
        const prodFinal   = row.CDARVPRODFIM;
        
        if(!validaProduto(prodInicial, prodFinal)){
            field.clearValue();
        }
    };
    
    function concatenaEscolhas(currentRow) {
        let row = angular.copy(currentRow);
 		let array = row.IDBAIXAAF;
 		
 		row.IDBAIXAAF = '';

        for(let i = 0; i<array.length; i++){
        
             switch (array[i]) {
         	    case '1':
         	        row.IDBAIXAAF += '1';
         	        break;
         	    case '2':
         	        row.IDBAIXAAF += '_2';
         	        break;
         	    case '3': 
         	        row.IDBAIXAAF += '_3';
         	        break;
         	    case '4':
         	        row.IDBAIXAAF += '_4';
         	        break;
         	    case '5':
         	        row.IDBAIXAAF += '_5';
         	        break;
         	}
        }	
		
 		if (row.IDBAIXAAF === '') row.IDBAIXAAF = '0';
     	if (row.IDBAIXAAF !== '') row.P_IDBAIXAAF = row.IDBAIXAAF;

        return row;
    }
}

Configuration(function(ContextRegister) {
    ContextRegister.register('Cmp07500JustificativaAfsController', Cmp07500JustificativaAfsController);
});