var Cmp06900AlteracaoAutomaticaSolicitacaoComprasController = function(General, ScreenService, MessageService, ZhFilterPreferences, templateManager, ZHPromise, Utilities) {
	var paramsParaSupri;
	var self = this;
	
	const permissionsArray = {
        'ALTERAR_DTENTREGA'     : false,
        'ALTERAR_PRODUTO'       : false,
        'EXCLUIR_PRODUTO'       : false,
        'AUMENTAR_QUANTIDADE'   : false,
        'DIMINUIR_QUANTIDADE'   : false,
        'percentAumentar'       : undefined,
        'percentDiminuir'       : undefined
    };
		
	var validaRegras = function(widget) {
		validaRegraJustificativa(widget);
		validaRegraQuantidadeVolume(widget.getParent().getWidget('alteracao_automatica_produto_widget'));
	};
	
	function getParametros() {
		return General.callRestEngine('cmp#/crud/parasupri', 'FilterData',
				[
					{
						"name": "CDFILIAL",
						"operator": "=",
						"value": getLocalVar('CDFILCENTCMP')
					},
					{
						"name": "NRORG",
						"operator": "=",
						"value": getLocalVar('NRORG')
					}
				]);
	}
	
	this.widgetOnEnterOnce = function(widget) {
		General.callRestEngine("cmp#/getCdFilCentCmp", "Row", {}).then(function(response) {
            setLocalVar('NMFILCENTCMP', response.dataset.data.NMFILCENTCMP);
            setLocalVar('CDFILCENTCMP', response.dataset.data.CDFILCENTCMP);
            
            getParametros().then(function(success) {
			    paramsParaSupri = success.dataset.parasupri[0];
			    
			    validaRegras(widget);
			    
			    if(widget.ABERTA_POR) {
			    	widget.getAction('voltar_lancamento_solicitacao_compras').isVisible = true;
				} else {
			    	Utilities.startFilter(widget);
					widget.getAction('voltar_lancamento_solicitacao_compras').isVisible = false;
				}
				
				General.callRestEngine('cmp_solicitacao_solicitacaoCompras#/getPermissoesAlt', 'Row', {}).then(function(callback) {
		            const permissoes = callback.dataset.permissoes;
		            
		            if(permissoes) {
		                permissoes.forEach(function (value) {
		                    permissionsArray[value.IDAUTALTEPRODSOLI] = true;
		                    
		                    if(value.IDAUTALTEPRODSOLI == 'AUMENTAR_QUANTIDADE') {
		                        permissionsArray.percentAumentar    = value.PEALTEQTDESOLI;
		                    }
		                    if(value.IDAUTALTEPRODSOLI == 'DIMINUIR_QUANTIDADE') {
		                        permissionsArray.percentDiminuir    = value.PEALTEQTDESOLI;
		                    }
		                });
		            }
		        }, function(err) {
		            ScreenService.showMessage(err.data.error);
		        });
				
			    complementaDataSourceFilterSubGrupo(widget);
			});
        }, function(error) {
			return MessageService.showMessageByCode(error.data ? 'cmp#' + error.data.error : 'Timeout', null, { type: 'ERROR' });
		});
	};
	
	/**
	 * Fecha todos os popUps, limpa as rows selecionadas e atualiza o Grid.
	 * 
	 * Utilizado por:
	 * * Alteração Automática de Produto;
	 * * Alteração Automática de Data de Entrega.
	 */
	var closePopupAndReloadGrid = function(actualWidget) {
		var widgetGrid = actualWidget.container.getWidget('cmp06900_alteracao_automatica_solicitacao_compras_grid');
		actualWidget.currentRow = {};			
		ScreenService.closePopup(true);
		
		widgetGrid.dataSource.clearCheckedRows();
		
		widgetGrid.reload().then(function() {
			widgetGrid.activate();
		});
	};
	
	/**
     * ########################################################################
     * ########################### >>> FILTRO <<< #############################
     * ########################################################################
     */
     
	this.setFilterInitValues = function(widget) {
	    var filterRow = {
	    	'ENTREGA': [
	    		'ED',
	    		'OL'
	    	]
	    };
	    
	    ZhFilterPreferences.setOriginalFilter(widget.id, filterRow);
	};
	
	this.alteraDataSourceFilterUnidade = function(widget) {
		var fieldUnidade = widget.getField('NMFILIAL'),
			dataSourceFilter = [
				{
					'name': 'NRORG',
					'operator': '=',
					'value': getLocalVar('NRORG')
				},
				{
					'name': 'CDOPERADOR',
					'operator': '=',
					'value': getLocalVar('CDOPERADOR')
				},
				{
					'name': 'CDGRUPFILI',
					'operator': '=',
					'value': widget.currentRow.CDGRUPFILI || 'T'
				}
			];
			
		fieldUnidade.clearValue();
		fieldUnidade.dataSource.load(dataSourceFilter);
	};
    
    this.onChangeAgrupamentoUnidade = function(widget) {
    	this.alteraDataSourceFilterUnidade(widget);
    	this.alteraDataSourceFilterNumero(widget);
    };
	
    this.alteraDataSourceFilterNumero = function(widget) {
    	var fieldNumero = widget.getField('NRSOLI'),
    		dataSourceFilter= [
	    		{
	                "name": "P_CDAGRUPFILI",
	                "operator": "=",
	                "value": widget.currentRow.CDGRUPFILI ? widget.currentRow.CDGRUPFILI : 'T'
	            },
	            {
	            	"name": "P_CDOPERADOR",
	            	"operator": "=",
	            	"value": getLocalVar('CDOPERADOR')
                },
	            {
	                "name": "NRORG",
	                "operator": "=",
	                "value": getLocalVar('NRORG')
	            },
        	    {
        	    	"name": "P_CDFILIAL",
        	    	"operator": "=",
        	    	"value": widget.currentRow.NMFILIAL ? widget.currentRow.NMFILIAL.join('_') : getLocalVar('CDFILIAL')
        	    },
        	    {
        	    	"name": "P_TSOLICITA",
        	    	"operator": "=",
        	    	"value": (widget.currentRow.DTSOLICITACAO.start && widget.currentRow.DTSOLICITACAO.end) ? '' : 'T'
        	    },
        	    {
        	    	"name": "P_DTSOLINI",
        	    	"operator": "=",
        	    	"value": widget.currentRow.DTSOLICITACAO ? widget.currentRow.DTSOLICITACAO.start ? widget.currentRow.DTSOLICITACAO.start : '' : ''
        	    },
        	    {
        	    	"name": "P_DTSOLFIN",
        	    	"operator": "=",
        	    	"value": widget.currentRow.DTSOLICITACAO ? widget.currentRow.DTSOLICITACAO.end ? widget.currentRow.DTSOLICITACAO.end : '' : ''
        	    },
        	    {
        	    	"name": "P_TENTREGA",
        	    	"operator": "=",
        	    	"value": (widget.currentRow.DTENTREGA.start && widget.currentRow.DTENTREGA.end) ? '' : 'T'
        	    },
        	    {
        	    	"name": "P_DTENTRINI",
        	    	"operator": "=",
        	    	"value": widget.currentRow.DTENTREGA ? widget.currentRow.DTENTREGA.start ? widget.currentRow.DTENTREGA.start : '' : ''
        	    },
        	    {
        	    	"name": "P_DTENTRFIN",
        	    	"operator": "=",
        	    	"value": widget.currentRow.DTENTREGA ? widget.currentRow.DTENTREGA.end ? widget.currentRow.DTENTREGA.end : '': ''
        	    },
        	    {
        	    	"name": "P_TPRODUTO",
        	    	"operator": "=",
        	    	"value": (widget.currentRow.CDPRODINI && widget.currentRow.CDPRODFIN) ? '' : 'T'
        	    },
        	    {
        	    	"name": "P_CDPRODINI",
        	    	"operator": "=",
        	    	"value": widget.currentRow.CDPRODINI ? widget.currentRow.CDPRODINI : ''
        	    },
        	    {
        	    	"name": "P_CDPRODFIN",
        	    	"operator": "=",
        	    	"value": widget.currentRow.CDPRODFIN ? this.preencheCaractereDireita(widget.currentRow.CDPRODFIN) : ''
        	    }
    		];
    		
    	fieldNumero.clearValue();
    	fieldNumero.dataSourceFilter = dataSourceFilter;
    	fieldNumero.reload();
		
		const fieldDestSoli = widget.getField("NMDESTSOLI");
		const dtSoruceNmDestSoli = [
			 {
			 	"name": "P_CDFILIAL",
	            "operator": "=",
	            "value": widget.currentRow.NMFILIAL ? widget.currentRow.NMFILIAL.join('_') : 'T'
			 }
		];
		
		fieldDestSoli.clearValue();
		fieldDestSoli.dataSource.load(dtSoruceNmDestSoli);
    };
    
    function complementaDataSourceFilterSubGrupo(widget) {
    	var params = {
    		'P_CDFILCENTCMP': getLocalVar('CDFILCENTCMP')
    	};
    	
    	General.callRestEngine('cmp_solicitacao_solicitacaoCompras#/get_codigo_grup_prod', "Row", params).then(function(success) {
	    	widget.getField('CDSUBGRPROD').dataSourceFilter = [
	    		{
	                "name": "CDGRUPPROD",
	                "operator": "=",
	                "value": success.dataset.data[0].CDGRUPPROD
	            }
			];
    	},
    	function(err) {
    		ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
    	});
    }
	
	this.limpaLabelObrigatorioProdutos = function(currentRow) {
		if (currentRow.$error) {
			currentRow.$error.NMPRODINI = [];
			currentRow.$error.NMPRODFIN = [];
		}
	};
	
	this.validaProdutoInicialAndFinal = function(actualField) {
		var widget = actualField.getParent(),
			currentRow = widget.currentRow,
			otherField = actualField.name === 'NMPRODINI' ? widget.getField('NMPRODFIN') : widget.getField('NMPRODINI'),
			limpaLabelObrigatorio = true,
			isProdutoValido;
		
		if (currentRow.CDPRODINI || currentRow.CDPRODFIN) {
			actualField.validations = { 'required': true };
			otherField.validations = { 'required': true };
			
			if (currentRow.CDPRODINI && currentRow.CDPRODFIN) {
				isProdutoValido = General.comparaPratoProduto(currentRow.CDPRODINI, currentRow.CDPRODFIN, getLocalVar('CDPICTPROD'));
				if (!isProdutoValido) {
					MessageService.showMessageByCode("PRODUTO_INICIAL_MENOR_IGUAL_FINAL");
					actualField.clearValue();
					limpaLabelObrigatorio = false;
				}
			} 
		} else {
			actualField.validations = {};
			otherField.validations = {};
		}
		
		if (limpaLabelObrigatorio) {
			this.limpaLabelObrigatorioProdutos(currentRow);
		}
	};
	
	this.preparaFiltro = function(args) {
		
		var filterRow = args.e.preference.FILTER_ROW,
			customFilterRow;

		if(typeof(filterRow) === 'object'){
            customFilterRow = {
				'P_CDFILIAL': this.concatArrayForParams(filterRow.NMFILIAL),
				'P_CDAGRUPFILI': filterRow.CDGRUPFILI ? filterRow.CDGRUPFILI : 'T',
				'P_NRSOLICMP': this.concatArrayForParams(filterRow.NRSOLI),
				'P_CDOPERADOR': getLocalVar('CDOPERADOR'),
				'P_ED': this.getEntrega(filterRow.ENTREGA, 'ED'),
				'P_OL': this.getEntrega(filterRow.ENTREGA, 'OL'),
				'P_CDGRUPROD': this.concatArrayForParams(filterRow.CDSUBGRPROD)
            };
            
            if (filterRow.CDPRODINI && filterRow.CDPRODFIN) {
            	customFilterRow.P_CDPRODINI = filterRow.CDPRODINI;
				customFilterRow.P_CDPRODFIN = this.preencheCaractereDireita(filterRow.CDPRODFIN);
				customFilterRow.P_TPRODUTO = null;
            } else {
            	customFilterRow.P_CDPRODINI = null;
				customFilterRow.P_CDPRODFIN = null;
				customFilterRow.P_TPRODUTO = 'T';
            }
            
            if (filterRow.DTENTREGA.start && filterRow.DTENTREGA.end) {
            	customFilterRow.P_DTENTRINI = filterRow.DTENTREGA.start;
				customFilterRow.P_DTENTRFIN = filterRow.DTENTREGA.end;
				customFilterRow.P_TENTREGA = null;
            } else {
            	customFilterRow.P_DTENTRINI = null;
				customFilterRow.P_DTENTRFIN = null;
				customFilterRow.P_TENTREGA = 'T';
            }
            
            if (filterRow.DTSOLICITACAO.start && filterRow.DTSOLICITACAO.start) {
            	customFilterRow.P_DTSOLINI = filterRow.DTSOLICITACAO.start;
				customFilterRow.P_DTSOLFIN = filterRow.DTSOLICITACAO.end;
				customFilterRow.P_TSOLICITA = null;
            } else {
            	customFilterRow.P_DTSOLINI = null;
				customFilterRow.P_DTSOLFIN = null;
				customFilterRow.P_TSOLICITA = 'T';
            }
            
            args.e.preference.CUSTOM_FILTER_ROW = customFilterRow;
        }
    };
     
     
	/**
     * ########################################################################
     * ########################## >>> RELATÓRIO <<< ###########################
     * ########################################################################
     */
	
	this.abrirTelaRelatorio = function(widget) {
		ScreenService.openWindow('cmp_solicitacao_relatorios#cmp03200_alteracao_nos_produtos_da_solitacao').then(function() {
			templateManager.container.getWidget('alteracaoProdutosSolicitacao').OPENED = true;
		});
	};
	
	/**
     * ########################################################################
     * ########################## >>> UTILIDADE <<< ###########################
     * ########################################################################
     */
     
	this.applyFieldValue = function (selectedField, value) {
		if (value) {
			selectedField.setValue(value);
		} else {
			selectedField.applyDefaultValue();
		}
	};
	
	var getNewValidations = function(actualValidations) {
		var validationsIsEmpty;
		
		if (typeof(actualValidations) === 'object') {
			validationsIsEmpty = Util.isEmptyObject(actualValidations);
		} else {
			validationsIsEmpty = Util.isEmptyOrBlank(actualValidations);
		}
		
		return validationsIsEmpty ? {required: true} : {};
	};
	
	this.toggleField = function (widget, selectedFieldName, value) {
		var selectedField = widget.getField(selectedFieldName);
		
		selectedField.readOnly = !selectedField.readOnly;
		selectedField.validations = getNewValidations(selectedField.validations);
		
		if (selectedField.isReadOnly()) {
			selectedField.setValue('');
			
			if (widget.currentRow.$error)
				delete widget.currentRow.$error[selectedFieldName];
				
			templateManager.updateTemplate();
		} else {
			this.applyFieldValue(selectedField, value);
		}
	};
	
	this.getEntrega = function(arrayEntrega, entregaForSearch) {
		var entrega = arrayEntrega.filter(function(item) {
			return item === entregaForSearch;
		})[0];
		
		switch (entrega) {
			case 'ED':
				return 'P';
				
			case 'OL':
				return 'O';
			
			default:
				return null;
		}
	};
	
    this.voltarAlteracaoAutomatica = function(args) {
		ScreenService.closePopup();
    };
	
	this.voltarDetail = function(widget) {
		ScreenService.closeSwipe();
		widget.reload();
	};
	
	var verifyMinValue = function(field) {
        var value = angular.copy(field.value()),
        	minValue = '-99.99';
        
        if(typeof(value) == 'string') {
            value = value.split('.').join('');
            value = value.replace(',', '.');
        } 
        
        if(value && parseFloat(value) < parseFloat(minValue)) {
            field.setValue('0');
            MessageService.showMessageByCode("VLR_MENOR_MENOS_99");
        }
    };
    
    var trataValorNaoPreenchido = function(field) {
    	if (Util.isEmptyOrBlank(field.value())) {
    		field.setValue('0');
    	}
    };
	
	/**
     * Retorna a concatenação do array passado pro parâmetro. 
     * 
     * @param {Array} arr - array a ser concanetado.
     * @param {string} defaultValue - Valor a ser retornado caso o arr esteja
     * vazio ou em branco.
     * @returns {string} Array concatenado ou o defaultValue passado por
     * parâmetro. Se não houver defaultValue, retorna 'T'.
     */
    this.concatArrayForParams = function (arr, defaultValue) {
        if(!Util.isEmptyOrBlank(arr)) {
            return arr.join('_');
        } else {
            return defaultValue || 'T';
        }
    };
	
	this.preencheCaractereDireita = function(string){
        var pad = 'ZZZZZZZZZZ';
        return string + pad.substr(0, pad.length - string.length);    
    };
    
    this.isQuantidadeZero = function(quantidade) {
    	return quantidade == 0 || quantidade === '0,000' ? true : false;
    };
    
    this.voltarLancSoliCmp = function() {
    	ScreenService.openWindow('cmp_solicitacao_solicitacaoCompras#cmp03100_lancamento_de_solicitacao_de_compras').then(function() {
    		delete templateManager.containers['cmp_solicitacao_solicitacaoCompras#/cmp06900_alteracao_automatica_solicitacao_compras'];
    	});
    };
	
	/**
     * ########################################################################
     * ################## >>> ALTERAR ENTREGA ED/OL <<< #######################
     * ########################################################################
     */
     
    this.alteraEntrega = function(widget, newStatus, confirmMessage) {
    	var itensSelecionados = widget.dataSource.getCheckedRows();
		
    	ScreenService.confirmMessage(confirmMessage, 'CONFIRMATION',
    	function(success) {
    		var params = {
				"ITENS_SELECIONADOS": itensSelecionados,
				"NEW_STATUS": newStatus,
				"CDOPERADOR": getLocalVar('CDOPERADOR')
			};
			
    		General.callRestEngine("cmp_solicitacao#/alterar_entrega", "Row", params).then(
    			function(success) {
    				ScreenService.closePopup();
    				widget.reload();
				},
				function(err) {
					ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
				});
    	});
    };
    
    this.alteraParaEntregaOL = function(widget) {
    	if (paramsParaSupri.IDUTILCONSSOLIOL === 'S') {
    		this.alteraEntrega(widget, 'O', ScreenService.i18n('Confirmar alteração dos itens para entrega via OL? A alteração ocorrerá apenas se os mesmos estiverem devidamente parametrizados.'));
    	} else {
    		MessageService.showMessageByCode("OPR_BLOCK_PARAM_OPL_DESMARCADO");
    	}
    };
    
    this.alteraParaEntregaED = function(widget) {
	    this.alteraEntrega(widget, 'P', ScreenService.i18n('Confirmar alteração dos itens para entrega direta (ponto-a-ponto)? A alteração ocorrerá para itens de solicitações que não possuem pedidos do OL já gerados.'));
    };
     
    /**
     * ########################################################################
     * ############### >>> ATUALIZAÇÃO DE ITENS DO GRID <<< ###################
     * ########################################################################
     * 
     * Responsável por atualizar:
     * - Quantidade;
     * - Marca;
     * - Justificativa.
     */
     
	var validaRegraJustificativa = function(widget) {
		if (paramsParaSupri.IDAUDALTSOL === 'N') {
			widget.getField('DSJUSTSOL').isVisible = false;
		}
	};
	
    this.beforeEditSolicitacao = function(widget) {
    	var fieldMarca = widget.getField('NMMARCA'),
    		currentRow = widget.currentRow,
	    	isFilialOL = currentRow.IDFUNCAOFILI === 'O' ? true : false;
    	
    	General.edit(widget);
    	
    	if (isFilialOL) {
	    	fieldMarca.readOnlyOnEdit = false;
    	    fieldMarca.dataSourceFilter = [
	    		{
	                'name': 'CDARVPROD',
	                'operator': '=',
	                'value': currentRow.CDARVPROD
	            },
	            {
	                'operator': 'ORDER_BY',
	                'name': [
	                    {
	                        'name': 'CDMARCA',
	                        'direction': 'ASC'
	                    }
	                ]
	            }
	        ];
    	} else {
    		fieldMarca.readOnlyOnEdit = true;
    	}
    };
    	
    this.salvarAlteracoesSolicitacao = function(widget, deleteItem, inlineEdit) {
    	let rows = widget.dataSource.data.filter(rowsModificadas => rowsModificadas.changed);
    	let params = [];
    	rows.forEach(function(row) {
    		params.push({
    			'IDAUDALTSOL'   : paramsParaSupri.IDAUDALTSOL,
				'IDTIPLAN'      : row.IDTIPLAN,
				'IDUTAPROVSOL'  : row.IDUTAPROVSOL,
				'IDPERALTSAPR'  : row.IDPERALTSAPR,
				'IDSOLIAPROV'   : row.IDSOLIAPROV,
				'NRSEQUCONSOL'  : row.NRSEQUCONSOL,
				'QTSOLIPROD'    : row.QTSOLIPROD,
				'QTSOLIORIG'    : row.changed_QTSOLIPROD,
				'CDMARCA'       : row.CDMARCA ? row.CDMARCA : null,
				'CDFILSOLI'     : row.CDFILSOLI,
				'CDFILLAN'      : row.CDFILLAN,
				'NRSOLICMP'     : row.NRSOLICMP,
				'CDPRODUTO'     : row.CDARVPROD,
				'DTPROGENTR'    : row.DTPROGENTR,
				'STATUS'        : row.STATUS,
				'DSJUSTOPER'    : widget.getField('DSJUSTSOL').isVisible ? row.DSJUSTSOL : 'Alteração - CMP06900 Mobile',
				'CDOPERADOR'    : getLocalVar('CDOPERADOR'),
				'CDMARCA_OLD'   : row.CDMARCA ? row.CDMARCA : null,
				'CDOPERADOR_OLD': getLocalVar('CDOPERADOR'),
				'CDFILSOLI_OLD' : row.CDFILSOLI,
				'CDFILLAN_OLD'  : row.CDFILLAN,
				'NRSOLICMP_OLD' : row.NRSOLICMP,
				'CDPRODUTO_OLD' : row.CDPRODUTO,
				'DTPROGENTR_OLD': row.DTPROGENTR,
				'QTSOLIPROD_OLD': row.changed_QTSOLIPROD ? row.changed_QTSOLIPROD : row.QTSOLIPROD,
				'STATUS_OLD'    : row.STATUS
    		});
    	});
		
		General.callRestEngine('cmp_solicitacao_solicitacaoCompras#/salvar_alteracoes_solicitacao', 'Row', params).then(function(success) {
		    if (deleteItem) {
		    	this.voltarDetail(widget);
		    	MessageService.showMessageByCode("EXCLUIDO_SUCCESS");
		    } else {
			    MessageService.showMessageByCode("SALVO_SUCESSO");
	    		widget.currentRow.DSJUSTSOL = "";
			    if(inlineEdit){
			    	widget.rollbackInlineEdit();
			    	widget.reload();
        			widget.list();
			    } else {
			    	widget.view();
			    }
		    }
		}.bind(this),
		function(err) {
		    ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
		});
    };
    
	this.acionaSalvarAlteracoesSolicitacao = function(widget) {
		let inlineEdit = widget.currentRow.changed_QTSOLIPROD ? true : false;
		let justificativa = inlineEdit && widget.getField('DSJUSTSOL').isVisible && !widget.currentRow.DSJUSTSOL;
		
		var verificaQuantidade = this.verifyQuantidadeEditPermissions(widget);
		
		verificaQuantidade = verificaQuantidade == undefined ? true : verificaQuantidade;
		
		var changedRows = widget.dataSource.data.filter(function(row) {
			return row.changed === true;
		});
		var changedSemJust = changedRows.filter(function(row) {
			return row.DSJUSTSOL == null || row.DSJUSTSOL == "" || row.DSJUSTSOL == undefined || !row.DSJUSTSOL;	
		});
		
		if (widget.isValid()) {
			if(verificaQuantidade) {
				if (this.isQuantidadeZero(widget.currentRow.QTSOLIPROD)) {
					ScreenService.confirmMessage('Confirma exclusão do registro?', 'CONFIRMATION', function() {
						this.salvarAlteracoesSolicitacao(widget, true, false);
					}.bind(this));
				} else {
					if(changedSemJust.length > 0) {
						if(paramsParaSupri.IDAUDALTSOL == 'S')
							MessageService.showMessageByCode("JUSTIFICATIVA_REQUIRED", "ERROR");
						else
							this.salvarAlteracoesSolicitacao(widget, false, false);
					} else {
						this.salvarAlteracoesSolicitacao(widget, false, false);
					}
				}
			}
		} else {
			if (justificativa) {
				if(paramsParaSupri.IDAUDALTSOL == 'S')
					MessageService.showMessageByCode("JUSTIFICATIVA_REQUIRED", "ERROR");
				else
					this.salvarAlteracoesSolicitacao(widget, false, false);
			}
		}
	};
     
    /**
     * ########################################################################
     * ########## >>> ATUALIZAÇÃO AUTOMÁTICA DE DATA DE ENTREGA <<< ###########
     * ########################################################################
     */
     
	this.openWidgetAlteracaoAutomaticaDataEntrega = function(widget) {
		const popUpWidget = widget.getParent().getWidget('alteracao_automatica_data_entrega_widget');
		const widgetGrid = templateManager.container.getWidget('cmp06900_alteracao_automatica_solicitacao_compras_grid');
		const checkedRowsGrid = widget.getCheckedRows();
		
		popUpWidget.currentRow.NOVADTENTREGA = moment().format('L');
		popUpWidget.currentRow.TIPOJUST = 'P';
		
		if(paramsParaSupri.IDAUDALTSOL == 'S') {
			popUpWidget.getField("TIPOJUST").isVisible = true;
			popUpWidget.getField("DSJUSTOPER").isVisible = true;
			
			popUpWidget.currentRow.TIPOJUST = 'P';
			popUpWidget.currentRow.DSJUSTOPER = '';
			
			popUpWidget.getField("DSJUSTOPER").template = "zh-select-autocomplete#field/select-autocomplete.html";
			
			popUpWidget.getField("DSJUSTOPER").reload();
		} else {
			popUpWidget.getField("TIPOJUST").isVisible = false;
			popUpWidget.getField("DSJUSTOPER").isVisible = false;
		}
		
		if(paramsParaSupri.IDBLOQALTSOLAUT === 'S') {
			if(permissionsArray.ALTERAR_DTENTREGA) {
				ScreenService.openPopup(popUpWidget);
			} else {
				var positiveRowsM = checkedRowsGrid.filter(function(row) {
					return (row.IDTIPLAN === 'M');
				});
				
				if(positiveRowsM.length == checkedRowsGrid.length) {
					ScreenService.openPopup(popUpWidget);
				} else {
					var negativeRowsM = checkedRowsGrid.filter(function(row) {
						return (row.IDTIPLAN === 'A' || row.IDTIPLAN === 'C');
					});
					var rowsToMessageM = [];
					var stringProdM;
					
					negativeRowsM.forEach(row => {
						var prod = "Produto: " + row.PRODUTO + ", Solicitação: " + row.NRSOLICMP;
						
						rowsToMessageM.push(prod);
					});
					
					stringProdM = rowsToMessageM.join("<br>");
					
					MessageService.showMessageByCode("ALTAUTSOL_BLOCK_PRODS", { PRODUTOS: stringProdM }).then(function(confirmed) {
						ScreenService.closePopup(true);
								
						widgetGrid.reload().then(function() {
							widgetGrid.activate();
						});
					});
				}
			}
		} else {
			ScreenService.openPopup(popUpWidget);
		}
	};
     
    var montaParametrosAlteracaoAutomaticaDataEntrega = function(widgetAltAutomaticaDataEntrega) {
    	var row = widgetAltAutomaticaDataEntrega.currentRow,
    		checkedRows = widgetAltAutomaticaDataEntrega.getParent().dataSource.getCheckedRows(),
            parametros = {
				'DTPROGENTR_NEW': row.NOVADTENTREGA,
				'DSJUSTOPER_NEW': row.DSJUSTOPER,
				'CDOPERADOR': getLocalVar('CDOPERADOR'),
				'ITENS_SELECIONADOS': checkedRows
            };
            
        return parametros;
    };
    
    var getMessageForAlteracaoAutomaticaDataEntrega = function(widgetAltAutomaticaDataEntrega) {
    	var checkedRows = widgetAltAutomaticaDataEntrega.getParent().dataSource.getCheckedRows(),
    		stMsgConf = 'Confirmar alteração da data de entrega dos itens selecionados?',
    		dtMultData;
    	
    	for (var i = checkedRows.length; i--;) {
    		if (dtMultData) {
    			if (dtMultData != checkedRows[i].DTPROGENTR) {
    				stMsgConf = 'Houve seleção de entregas distintas para alteração automática. Deseja confirmar a operação?';
    				break;
    			}
    		} else {
               dtMultData = checkedRows[i].DTPROGENTR;
    		}
    	}
    	
    	return stMsgConf;
    };
    
    this.confirmaAlteracaoAutomaticaDataEntrega = function(widgetAltAutomaticaDataEntrega) {
    	if (widgetAltAutomaticaDataEntrega.isValid()) {
    		var message = getMessageForAlteracaoAutomaticaDataEntrega(widgetAltAutomaticaDataEntrega);
    		
    		ScreenService.confirmMessage(message, 'CONFIRMATION', function(success) {
			    var parametros = montaParametrosAlteracaoAutomaticaDataEntrega(widgetAltAutomaticaDataEntrega);
			
				General.callRestEngine("cmp_solicitacao#/alteracao_automatica_data_entrega", "Row", parametros).then(
					function(success) {
						closePopupAndReloadGrid(widgetAltAutomaticaDataEntrega);
					},
					function(err) {
						MessageService.showMessageByCode(err.data ? 'cmp#' + err.data.error : 'Timeout', null, { type: 'ERROR' });
					});
			});
    	}
    };
    
    /**
     * ########################################################################
     * ############## >>> ATUALIZAÇÃO AUTOMÁTICA DE PRODUTO <<< ###############
     * ########################################################################
     */
     
	var validaRegraQuantidadeVolume = function(widget) {
		var fieldQtdVolume = widget.getField('QUANTIDADE_VOLUMES'),
			fieldHabQtdVolume = widget.getField('HABILITAR_QTD_VOL');
			
		if (paramsParaSupri.IDUTQTDEVOLU === 'N') {
			fieldHabQtdVolume.isVisible = false;
			fieldHabQtdVolume.checked = false;
			
			fieldQtdVolume.isVisible = false;
			fieldQtdVolume.readOnly = true;
		} else {
			fieldHabQtdVolume.isVisible = true;
			fieldQtdVolume.isVisible = true;
		}
	};
	
	this.openWidgetAlteracaoAutomaticaProduto = function(widget) {
		var popUpWidget = widget.getParent().getWidget('alteracao_automatica_produto_widget'),
			fieldProduto = popUpWidget.getField('NMPRODUTO'),
			fieldQtd = popUpWidget.getField('QUANTIDADE_CAD'),
			fieldQtdVolume = popUpWidget.getField('QUANTIDADE_VOLUMES');
		
		popUpWidget.newRow();
		
		fieldProduto.readOnly = true;
		fieldQtd.readOnly = true;
		fieldQtdVolume.readOnly = true;
		
		fieldProduto.validations = {};
		fieldQtd.validations = {};
		fieldQtdVolume.validations = {};
		
		popUpWidget.getField('AJUSTE_UNIDADE').isVisible = false;
		popUpWidget.getField('AJUSTE_QUANTIDADE').isVisible = false;
		
		popUpWidget.getField('HABILITAR_PROD').setValue('N');
		popUpWidget.getField('HABILITAR_QTD').setValue('N');
		popUpWidget.getField('HABILITAR_QTD_VOL').setValue('N');
		
		if(paramsParaSupri.IDAUDALTSOL == 'S') {
			popUpWidget.getField("TIPOJUST").isVisible = true;
			popUpWidget.getField("DSJUSTOPER").isVisible = true;
		
			popUpWidget.currentRow.TIPOJUST = 'P';
			popUpWidget.currentRow.DSJUSTOPER = '';
			
			popUpWidget.getField("DSJUSTOPER").template = "zh-select-autocomplete#field/select-autocomplete.html";
			
			popUpWidget.getField("DSJUSTOPER").reload();
		} else {
			popUpWidget.getField("TIPOJUST").isVisible = false;
			popUpWidget.getField("DSJUSTOPER").isVisible = false;
		}
		
		
		
	    ScreenService.openPopup(popUpWidget);
	};
	
	this.habilitarFieldsPercentual = function(widget, fieldToToggle, defaultValue) {
		var habilitarQtdIsChecked = widget.getField('HABILITAR_QTD').checked;
		var habilitarProdIsChecked = widget.getField('HABILITAR_PROD').checked;
		
		const widgetAlt = templateManager.container.getWidget("alteracao_automatica_produto_widget");
		const widgetGrid = templateManager.container.getWidget('cmp06900_alteracao_automatica_solicitacao_compras_grid');
		
		var checkedRowsGrid = widgetGrid.getCheckedRows();
			
		this.toggleField(widget, fieldToToggle, defaultValue);
		
		var positiveRows = checkedRowsGrid.filter(function(row) {
	    	return (row.IDTIPLAN === 'M');
	    });
	    var negativeRows = checkedRowsGrid.filter(function(row) {
	    	return (row.IDTIPLAN === 'A' || row.IDTIPLAN === 'C');
	    });
		var rowsToMessage = [];
	    var stringProd = "";
	    
	    
		if(fieldToToggle === "QUANTIDADE_CAD") {
			if(paramsParaSupri.IDBLOQALTSOLAUT === 'S') {
				if(!permissionsArray.AUMENTAR_QUANTIDADE && !permissionsArray.DIMINUIR_QUANTIDADE) {
	    			if(positiveRows.length != checkedRowsGrid.length) {
	    				negativeRows.forEach(row => {
							var prod = "Produto: " + row.PRODUTO + ", Solicitação: " + row.NRSOLICMP;
										
							rowsToMessage.push(prod);
						});
									
						stringProd = rowsToMessage.join("<br>");
					
						widgetAlt.getField("QUANTIDADE_CAD").setValue("");
						widgetAlt.getField("QUANTIDADE_CAD").readOnly = true;
						widgetAlt.getField("HABILITAR_QTD").setValue('N');
							
						delete widgetAlt.getField("QUANTIDADE_CAD").validations;
							
						habilitarQtdIsChecked = false;
						
						MessageService.showMessageByCode("ALTAUTSOL_BLOCK_PRODS", { PRODUTOS: stringProd }).then(confirmed => {
							ScreenService.closePopup(true);
								
							widgetGrid.reload().then(function() {
								widgetGrid.activate();
							});
						});
	    			}
				}
			} else {
				/**if(positiveRows.length != checkedRowsGrid.length) {
	    			negativeRows.forEach(row => {
						var prod = "Produto: " + row.PRODUTO + ", Solicitação: " + row.NRSOLICMP;
										
						rowsToMessage.push(prod);
					});
									
					stringProd = rowsToMessage.join("<br>");
					
					widgetAlt.getField("QUANTIDADE_CAD").setValue("");
					widgetAlt.getField("QUANTIDADE_CAD").readOnly = true;
					widgetAlt.getField("HABILITAR_QTD").setValue('N');
							
					delete widgetAlt.getField("QUANTIDADE_CAD").validations;
							
					habilitarQtdIsChecked = false;
						
					MessageService.showMessageByCode("ALTAUTSOL_BLOCK_PRODS", { PRODUTOS: stringProd }).then(confirmed => {
						ScreenService.closePopup(true);
								
						widgetGrid.reload().then(function() {
							widgetGrid.activate();
						});
					});
	    		}**/
			}
		}
		
		if (habilitarProdIsChecked && !habilitarQtdIsChecked) {
			widget.currentRow.AJUSTE_UNIDADE = '0';
			widget.currentRow.AJUSTE_QUANTIDADE = '0';
			
			widget.getField('AJUSTE_UNIDADE').isVisible = true;
			widget.getField('AJUSTE_QUANTIDADE').isVisible = true;
		} else {
			delete widget.currentRow.AJUSTE_UNIDADE;
			delete widget.currentRow.AJUSTE_QUANTIDADE;
			
			widget.getField('AJUSTE_UNIDADE').isVisible = false;
			widget.getField('AJUSTE_QUANTIDADE').isVisible = false;
		}
	};
    
    this.realizaCalculoPorcentagens = function(widgetAltAutomaticaProd, cdProdutoOld) {
    	var ajustes,
    		fieldAjusteUnidade = widgetAltAutomaticaProd.getField('AJUSTE_UNIDADE'),
    		fieldAjusteQuantidade = widgetAltAutomaticaProd.getField('AJUSTE_QUANTIDADE'),
    		row = {
	    		'CDPRODUTO_OLD': cdProdutoOld,
	    		'CDARVPROD': widgetAltAutomaticaProd.currentRow.CDARVPROD
    		};
    	
    	return General.callRestEngine('cmp_solicitacao_solicitacaoCompras#/calcular_ajustes', 'Row', row).then(function(success) {
    			ajustes = success.dataset.data[0];
    			
    			if (ajustes.AJUSTEUN) {
    				if(ajustes.AJUSTEUN == 0 || ajustes.AJUSTEUN == null)
    					fieldAjusteUnidade.setValue('0');
    				else
    					fieldAjusteUnidade.setValue(ajustes.AJUSTEUN);
    				fieldAjusteUnidade.reload();
    			} else {
    				fieldAjusteUnidade.setValue('0');
    			}
    			
    			if (ajustes.AJUSTEQTDE) {
    				if(ajustes.AJUSTEQTDE == 0 || ajustes.AJUSTEQTDE == null)
    					fieldAjusteQuantidade.setValue('0');
    				else
    					fieldAjusteQuantidade.setValue(ajustes.AJUSTEQTDE);
    				fieldAjusteQuantidade.reload();
    			} else {
    				fieldAjusteQuantidade.setValue('0');
    			}
    			fieldAjusteUnidade.reload();
    			fieldAjusteQuantidade.reload();
	        },
	        function(err) {
	            ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
	        });
    };
    
    this.verificaProduto = function(fieldProduto) {
    	var widgetAltAutomaticaProd = fieldProduto.getParent(),
    		widgetGrid = widgetAltAutomaticaProd.getParent(),
    		checkedRowsGrid = widgetGrid.dataSource.getCheckedRows();
    	
    	if (!Util.isEmptyOrBlank(widgetAltAutomaticaProd.currentRow.CDARVPROD)) {
	    	for (var i = 0; i < checkedRowsGrid.length; i++) {
	    		if (checkedRowsGrid[i].CDARVPROD === widgetAltAutomaticaProd.currentRow.CDARVPROD) {
	    			MessageService.showMessageByCode("NEW_PRODUCT_PRODUCT_ORIGIN");
		    		fieldProduto.clearValue();
		    		return;
	    		}
	    	}
	    	
    		this.realizaCalculoPorcentagens(widgetAltAutomaticaProd, checkedRowsGrid[0].CDARVPROD);
    	} else {
    		widgetAltAutomaticaProd.currentRow.AJUSTE_UNIDADE = '0';
    		widgetAltAutomaticaProd.currentRow.AJUSTE_QUANTIDADE = '0';
    	}
    };
    
    this.onChangeProduto = function(fieldProduto) {
    	this.verificaProduto(fieldProduto);
    };
    
    var montaParametrosAlteracaoAutomaticaProduto = function(widgetAltAutomaticaProd) {
    	var row = widgetAltAutomaticaProd.currentRow,
    		checkedRows = widgetAltAutomaticaProd.getParent().dataSource.getCheckedRows(),
            parametros = {
            	'P_IDBLOQALTSOLAUT': paramsParaSupri.IDBLOQALTSOLAUT,
            	'P_IDPRODUTO': widgetAltAutomaticaProd.getField('HABILITAR_PROD').checked,
				'P_IDQTDE': widgetAltAutomaticaProd.getField('HABILITAR_QTD').checked,
				'P_IDQTDEVOL': widgetAltAutomaticaProd.getField('HABILITAR_QTD_VOL').checked,
				'P_CDPRODUTO': row.CDPRODUTO || '',
				'P_QTDE': row.QUANTIDADE_CAD || '',
				'P_QTDEVOL': row.QUANTIDADE_VOLUMES || '',
				'P_AJUSTEUN': row.AJUSTE_UNIDADE || '',
				'P_AJUSTEQTDE': row.AJUSTE_QUANTIDADE || '',
				'P_FILIPROC': getLocalVar('CDFILIAL'),
				// Código do Produto a ser alterado
				'CDPRODUTO': checkedRows[0].CDPRODUTO,
				'ITENS_SELECIONADOS': checkedRows,
				'CDOPERADOR': getLocalVar('CDOPERADOR'),
                'NRORG': getLocalVar('NRORG')
            };
            
        return parametros;
    };
    
    var acionaAlteracaoAutomaticaProduto = function(widgetAltAutomaticaProd) {
    	const widget = widgetAltAutomaticaProd;
    	const checkedRows = widgetAltAutomaticaProd.getParent().dataSource.getCheckedRows();
    	const approvedRows = checkedRows.filter(function(row) {
    		return 	row.IDTIPLAN === 'M';
    	});
    	
    	var percentToBlock;
		var newQTSOLIPROD = widget.currentRow.QUANTIDADE_CAD.replaceAll('.', '').replaceAll(',', '.');
		var approvedRowsQTD = [], repprovedRowsQTD = [];
		var rowsToMessageQTD = [];
	    var stringProdQTD = "";
		            
		newQTSOLIPROD = parseFloat(newQTSOLIPROD);
    	
    	if(widget.currentRow.HABILITAR_PROD === 'S' && widget.currentRow.HABILITAR_QTD === 'N') {
    		if(paramsParaSupri.IDBLOQALTSOLAUT == 'S') {
    			if(permissionsArray.ALTERAR_PRODUTO) {
    				ScreenService.confirmMessage('Os itens selecionados serão atualizados com os valores informados. Deseja confirmar a operação?', 'CONFIRMATION', function(success) {
		    			var parametros = montaParametrosAlteracaoAutomaticaProduto(widgetAltAutomaticaProd);
		    			
						General.callRestEngine("cmp_solicitacao#/alteracao_automatica_produto", "Row", parametros).then( function(success) {
							closePopupAndReloadGrid(widgetAltAutomaticaProd);
						}, function(err) {
							ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
						});
					});
    			} else {
    				ScreenService.confirmMessage('Os itens selecionados serão atualizados com os valores informados. Deseja confirmar a operação?', 'CONFIRMATION', function(success) {
		    			var parametros = montaParametrosAlteracaoAutomaticaProduto(widgetAltAutomaticaProd);
		    			
		    			parametros.ITENS_SELECIONADOS = approvedRows;
		    			
						General.callRestEngine("cmp_solicitacao#/alteracao_automatica_produto", "Row", parametros).then( function(success) {
							closePopupAndReloadGrid(widgetAltAutomaticaProd);
						}, function(err) {
							ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
						});
					});
    			}
    		} else {
    			ScreenService.confirmMessage('Os itens selecionados serão atualizados com os valores informados. Deseja confirmar a operação?', 'CONFIRMATION', function(success) {
		    		var parametros = montaParametrosAlteracaoAutomaticaProduto(widgetAltAutomaticaProd);
		    			
		    		//parametros.ITENS_SELECIONADOS = approvedRows;
		    			
					General.callRestEngine("cmp_solicitacao#/alteracao_automatica_produto", "Row", parametros).then( function(success) {
						closePopupAndReloadGrid(widgetAltAutomaticaProd);
					}, function(err) {
						ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
					});
				});
    		}
    	} else if(widget.currentRow.HABILITAR_PROD === 'N' && widget.currentRow.HABILITAR_QTD === 'S') {
    		if(paramsParaSupri.IDBLOQALTSOLAUT == 'S') {
    			if(permissionsArray.AUMENTAR_QUANTIDADE || permissionsArray.DIMINUIR_QUANTIDADE) {
    				if(newQTSOLIPROD == 0) {
	    				MessageService.showMessageByCode("QTD_MAIOR_ZERO");
	    			} else {
	    				checkedRows.forEach(function(row) {
	    					if(row.IDTIPLAN === 'M') {
	    						approvedRowsQTD.push(row);
	    					} else {
	    						var oldQTSOLIPROD = row.QTSOLIPROD.replaceAll('.', '').replaceAll(',', '.');
	    						
		    					oldQTSOLIPROD = parseFloat(oldQTSOLIPROD);
		    					
		    					if((newQTSOLIPROD > oldQTSOLIPROD) && permissionsArray.AUMENTAR_QUANTIDADE) {
		    						if(permissionsArray.percentAumentar != null && permissionsArray.percentAumentar != undefined) {
		    							percentToBlock = oldQTSOLIPROD + (oldQTSOLIPROD * (parseFloat(permissionsArray.percentAumentar) / 100));
		    							
		    							if(newQTSOLIPROD > percentToBlock) {
					                        repprovedRowsQTD.push(row);
					                    } else {
					                        approvedRowsQTD.push(row);
					                    }
		    						} else {
		    							approvedRowsQTD.push(row);
		    						}
		    					} else if((newQTSOLIPROD < oldQTSOLIPROD) && permissionsArray.DIMINUIR_QUANTIDADE) {
		    						if(permissionsArray.percentDiminuir != null && permissionsArray.percentDiminuir != undefined) {
		    							percentToBlock = oldQTSOLIPROD - (oldQTSOLIPROD * (parseFloat(permissionsArray.percentDiminuir) / 100));
					                        
					                    if(newQTSOLIPROD < percentToBlock) {
					                    	repprovedRowsQTD.push(row);
					                    } else {
					                        approvedRowsQTD.push(row);
					                    }
		    						} else {
		    							approvedRowsQTD.push(row);
		    						}
		    					} else if(newQTSOLIPROD == oldQTSOLIPROD) {
		    						approvedRowsQTD.push(row);
		    					}
	    					}
	    				});
	    				
	    				if(approvedRowsQTD.length == checkedRows.length) {
	    					ScreenService.confirmMessage('Os itens selecionados serão atualizados com os valores informados. Deseja confirmar a operação?', 'CONFIRMATION', function(success) {
				    			var parametros = montaParametrosAlteracaoAutomaticaProduto(widgetAltAutomaticaProd);
				    			
								General.callRestEngine("cmp_solicitacao#/alteracao_automatica_produto", "Row", parametros).then( function(success) {
									closePopupAndReloadGrid(widgetAltAutomaticaProd);
								}, function(err) {
									ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
								});
							});
	    				} else {
	    					rowsToMessageQTD = [];
	    					
	    					stringProdQTD = "";
	    					
	    					repprovedRowsQTD.forEach(row => {
								var prod = "Produto: " + row.PRODUTO + ", Solicitação: " + row.NRSOLICMP;
										
								rowsToMessageQTD.push(prod);
							});
									
							stringProdQTD = rowsToMessageQTD.join("<br>");
							
							MessageService.showMessageByCode("ALTAUTSOL_BLOCK_PRODS_QTD", { PRODUTOS: stringProdQTD });
	    				}
	    			}
    			} else {
    				ScreenService.confirmMessage('Os itens selecionados serão atualizados com os valores informados. Deseja confirmar a operação?', 'CONFIRMATION', function(success) {
		    			var parametros = montaParametrosAlteracaoAutomaticaProduto(widgetAltAutomaticaProd);
		    			
		    			parametros.ITENS_SELECIONADOS = approvedRows;
		    			
						General.callRestEngine("cmp_solicitacao#/alteracao_automatica_produto", "Row", parametros).then( function(success) {
							closePopupAndReloadGrid(widgetAltAutomaticaProd);
						}, function(err) {
							ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
						});
					});
    			}
    		} else {
    			ScreenService.confirmMessage('Os itens selecionados serão atualizados com os valores informados. Deseja confirmar a operação?', 'CONFIRMATION', function(success) {
		    		var parametros = montaParametrosAlteracaoAutomaticaProduto(widgetAltAutomaticaProd);
		    			
		    		//parametros.ITENS_SELECIONADOS = approvedRows;
		    			
					General.callRestEngine("cmp_solicitacao#/alteracao_automatica_produto", "Row", parametros).then( function(success) {
						closePopupAndReloadGrid(widgetAltAutomaticaProd);
					}, function(err) {
						ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
					});
				});
    		}
    	} else {
    		if(paramsParaSupri.IDBLOQALTSOLAUT == 'S') {
    			if(permissionsArray.ALTERAR_PRODUTO && (permissionsArray.AUMENTAR_QUANTIDADE || permissionsArray.DIMINUIR_QUANTIDADE)) {
    				if(newQTSOLIPROD == 0) {
	    				MessageService.showMessageByCode("QTD_MAIOR_ZERO");
	    			} else {
	    				checkedRows.forEach(function(row) {
	    					if(row.IDTIPLAN === 'M') {
	    						approvedRowsQTD.push(row);
	    					} else {
	    						var oldQTSOLIPROD = row.QTSOLIPROD.replaceAll('.', '').replaceAll(',', '.');
	    						
		    					oldQTSOLIPROD = parseFloat(oldQTSOLIPROD);
		    					
		    					if((newQTSOLIPROD > oldQTSOLIPROD) && permissionsArray.AUMENTAR_QUANTIDADE) {
		    						if(permissionsArray.percentAumentar != null && permissionsArray.percentAumentar != undefined) {
		    							percentToBlock = oldQTSOLIPROD + (oldQTSOLIPROD * (parseFloat(permissionsArray.percentAumentar) / 100));
		    							
		    							if(newQTSOLIPROD > percentToBlock) {
					                        repprovedRowsQTD.push(row);
					                    } else {
					                        approvedRowsQTD.push(row);
					                    }
		    						} else {
		    							approvedRowsQTD.push(row);
		    						}
		    					} else if((newQTSOLIPROD < oldQTSOLIPROD) && permissionsArray.DIMINUIR_QUANTIDADE) {
		    						if(permissionsArray.percentDiminuir != null && permissionsArray.percentDiminuir != undefined) {
		    							percentToBlock = oldQTSOLIPROD - (oldQTSOLIPROD * (parseFloat(permissionsArray.percentDiminuir) / 100));
					                        
					                    if(newQTSOLIPROD < percentToBlock) {
					                    	repprovedRowsQTD.push(row);
					                    } else {
					                        approvedRowsQTD.push(row);
					                    }
		    						} else {
		    							approvedRowsQTD.push(row);
		    						}
		    					} else if(newQTSOLIPROD == oldQTSOLIPROD) {
		    						approvedRowsQTD.push(row);
		    					}
	    					}
	    				});
	    				
	    				if(approvedRowsQTD.length == checkedRows.length) {
	    					ScreenService.confirmMessage('Os itens selecionados serão atualizados com os valores informados. Deseja confirmar a operação?', 'CONFIRMATION', function(success) {
				    			var parametros = montaParametrosAlteracaoAutomaticaProduto(widgetAltAutomaticaProd);
				    			
								General.callRestEngine("cmp_solicitacao#/alteracao_automatica_produto", "Row", parametros).then( function(success) {
									closePopupAndReloadGrid(widgetAltAutomaticaProd);
								}, function(err) {
									ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
								});
							});
	    				} else {
	    					rowsToMessageQTD = [];
	    					
	    					stringProdQTD = "";
	    					
	    					repprovedRowsQTD.forEach(row => {
								var prod = "Produto: " + row.PRODUTO + ", Solicitação: " + row.NRSOLICMP;
										
								rowsToMessageQTD.push(prod);
							});
									
							stringProdQTD = rowsToMessageQTD.join("<br>");
							
							MessageService.showMessageByCode("ALTAUTSOL_BLOCK_PRODS_QTD", { PRODUTOS: stringProdQTD });
	    				}
	    			}
    			} else {
    				ScreenService.confirmMessage('Os itens selecionados serão atualizados com os valores informados. Deseja confirmar a operação?', 'CONFIRMATION', function(success) {
		    			var parametros = montaParametrosAlteracaoAutomaticaProduto(widgetAltAutomaticaProd);
		    			
		    			parametros.ITENS_SELECIONADOS = approvedRows;
		    			
						General.callRestEngine("cmp_solicitacao#/alteracao_automatica_produto", "Row", parametros).then( function(success) {
							closePopupAndReloadGrid(widgetAltAutomaticaProd);
						}, function(err) {
							ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
						});
					});
    			}
    		} else {
    			ScreenService.confirmMessage('Os itens selecionados serão atualizados com os valores informados. Deseja confirmar a operação?', 'CONFIRMATION', function(success) {
		    		var parametros = montaParametrosAlteracaoAutomaticaProduto(widgetAltAutomaticaProd);
		    			
		    		//parametros.ITENS_SELECIONADOS = approvedRows;
		    			
					General.callRestEngine("cmp_solicitacao#/alteracao_automatica_produto", "Row", parametros).then( function(success) {
						closePopupAndReloadGrid(widgetAltAutomaticaProd);
					}, function(err) {
						ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
					});
				});
    		}
    	}
    };
    
    this.confirmaAlteracaoAutomaticaProduto = function(widgetAltAutomaticaProd) {
    	var quantidade = widgetAltAutomaticaProd.currentRow.QUANTIDADE_CAD,
    		fieldHabProduto = widgetAltAutomaticaProd.getField('HABILITAR_PROD'),
    		cdProdutoOld = widgetAltAutomaticaProd.getParent().dataSource.checkedRows[0].CDARVPROD,
    		fieldsAtivos;
    	
    	if (widgetAltAutomaticaProd.isValid()) {
    		fieldsAtivos = widgetAltAutomaticaProd.fields.filter(function(field) {
    			return (field.name === 'NMPRODUTO' || field.name === 'QUANTIDADE_CAD') && field.isVisible === true && field.readOnly === false;
    		});
    		
			if (fieldsAtivos.length === 0) {
				MessageService.showMessageByCode("MINIMUM_ATTRIBUTE_REQUIRED");
				return;
			}
			
			if (quantidade && quantidade === '0') {
				MessageService.showMessageByCode("QTD_MAIOR_ZERO");
			} else if (fieldHabProduto.checked) {
				this.realizaCalculoPorcentagens(widgetAltAutomaticaProd, cdProdutoOld).then(function(success) {
					acionaAlteracaoAutomaticaProduto(widgetAltAutomaticaProd);
				}).catch(function(err) {
					ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
				});
			} else {
				acionaAlteracaoAutomaticaProduto(widgetAltAutomaticaProd);
			}
    	}
    };
	
	this.habilitarProduto = function(widgetAltAutomaticaProd) {
		var widgetGrid = widgetAltAutomaticaProd.getParent(),
			checkedRowsGrid = widgetGrid.dataSource.getCheckedRows(),
			produtoBase = checkedRowsGrid[0],
			permiteOperacao = true;
		
		
    	for (var i = 0; i < checkedRowsGrid.length; i++) {
    		if (checkedRowsGrid[i].CDARVPROD.length < 10) {
				MessageService.showMessageByCode("COMPLETE_LEVEL_REQUIRED");
				widgetAltAutomaticaProd.getField('HABILITAR_PROD').setValue('N');
				permiteOperacao = false;
	    		break;
    		}
    		
    		if (checkedRowsGrid[i].CDARVPROD !== produtoBase.CDARVPROD) {
				MessageService.showMessageByCode("OPR_BLOCK_DIF_PRODUCTS");
				widgetAltAutomaticaProd.getField('HABILITAR_PROD').setValue('N');
				permiteOperacao = false;
	    		break;
    		}
    	}
    	
    	if (permiteOperacao) {
    		if(paramsParaSupri.IDBLOQALTSOLAUT === 'S') {
    			if(permissionsArray.ALTERAR_PRODUTO) {
    				this.habilitarFieldsPercentual(widgetAltAutomaticaProd, 'NMPRODUTO', '');
    			} else {
    				var positiveRowsM = checkedRowsGrid.filter(function(row) {
						return (row.IDTIPLAN === 'M');
					});
					
					if(positiveRowsM.length == checkedRowsGrid.length) {
						this.habilitarFieldsPercentual(widgetAltAutomaticaProd, 'NMPRODUTO', '');
					} else {
						var negativeRowsM = checkedRowsGrid.filter(function(row) {
							return (row.IDTIPLAN === 'A' || row.IDTIPLAN === 'C');
						});
						
						var rowsToMessageM = [];
						var stringProdM;
						
						negativeRowsM.forEach(row => {
							var prod = "Produto: " + row.PRODUTO + ", Solicitação: " + row.NRSOLICMP;
							
							rowsToMessageM.push(prod);
						});
						
						stringProdM = rowsToMessageM.join("<br>");
						
						MessageService.showMessageByCode("ALTAUTSOL_BLOCK_PRODS", { PRODUTOS: stringProdM }).then(function(confirmed) {
							ScreenService.closePopup(true);
								
							widgetGrid.reload().then(function() {
								widgetGrid.activate();
							});
						});
					}
    			}
    		} else {
    			this.habilitarFieldsPercentual(widgetAltAutomaticaProd, 'NMPRODUTO', '');
    			/**var positiveRows = checkedRowsGrid.filter(function(row) {
					return (row.IDTIPLAN === 'M');
				});
					
				if(positiveRows.length == checkedRowsGrid.length) {
					this.habilitarFieldsPercentual(widgetAltAutomaticaProd, 'NMPRODUTO', '');
				} else {
					var blockedRows = checkedRowsGrid.filter(function(row) {
						return (row.IDTIPLAN === 'A' || row.IDTIPLAN === 'C');
					});
						
					var rowsToMessage = [];
					var stringProd;
						
					blockedRows.forEach(row => {
						var prod = "Produto: " + row.PRODUTO + ", Solicitação: " + row.NRSOLICMP;
							
						rowsToMessage.push(prod);
					});
						
					stringProd = rowsToMessage.join("<br>");
						
					MessageService.showMessageByCode("ALTAUTSOL_BLOCK_PRODS", { PRODUTOS: stringProd }).then(function(confirmed) {
						ScreenService.closePopup(true);
								
						widgetGrid.reload().then(function() {
							widgetGrid.activate();
						});
					});
				}**/
    		}
    	}
	};
	
	this.onChangeAjuste = function(field) {
		verifyMinValue(field);
		trataValorNaoPreenchido(field);
	};
	
	this.setStripe = function(args) {
		var widget = args.owner,
            filterRow = args.e.preference.FILTER_ROW;
    	
    	widget.container.getWidget('stripe').getField('STATUS').label = ScreenService.i18n('Status:') + filterRow.ENTREGA;
    	widget.container.getWidget('stripe').getField('NMPRODINI').label = ScreenService.i18n('Produto Inicial:') + filterRow.NMPRODINI;
    	widget.container.getWidget('stripe').getField('NMPRODFIN').label = ScreenService.i18n('Produto Final:') + filterRow.NMPRODFIN;
    };
    
    this.cancelaEditQuantidade = function(widget) {
        widget.rollbackInlineEdit();
        widget.list();
    };
    
    this.verifyQuantidadeEditPermissions = function(widget) {
    	const row = widget.currentRow;
    	
    	if((row.IDTIPLAN === 'A' || row.IDTIPLAN === 'C') && paramsParaSupri.IDBLOQALTSOLAUT === 'S') {
    		var percentToBlock;
    		var newQTSOLIPROD;
    		
    		if(widget.currentRow.QTSOLIPROD_inline && (typeof widget.currentRow.QTSOLIPROD_inline == "string"))
            	newQTSOLIPROD = widget.currentRow.QTSOLIPROD_inline.replaceAll('.', '').replaceAll(',', '.');
            else
            	newQTSOLIPROD = widget.currentRow.QTSOLIPROD.replaceAll('.', '').replaceAll(',', '.');
            	
            var oldQTSOLIPROD = widget.currentRow.QTSOLIORIG.replaceAll('.', '').replaceAll(',', '.');
            
            newQTSOLIPROD = parseFloat(newQTSOLIPROD);
            oldQTSOLIPROD = parseFloat(oldQTSOLIPROD);
            
            if(oldQTSOLIPROD == 0) {
            	oldQTSOLIPROD = widget.currentRow.QTSOLIPRODBKP.replaceAll('.', '').replaceAll(',', '.');
            	oldQTSOLIPROD = parseFloat(oldQTSOLIPROD);
            }
            
            if(newQTSOLIPROD == 0 && permissionsArray.EXCLUIR_PRODUTO) {
            	return true;
            } else if(permissionsArray.AUMENTAR_QUANTIDADE || permissionsArray.DIMINUIR_QUANTIDADE) {
    			if((newQTSOLIPROD > oldQTSOLIPROD) && permissionsArray.AUMENTAR_QUANTIDADE) {
                    if(permissionsArray.percentAumentar != null && permissionsArray.percentAumentar != undefined) {
                        percentToBlock = oldQTSOLIPROD + (oldQTSOLIPROD * (parseFloat(permissionsArray.percentAumentar) / 100));
                        
                        if(newQTSOLIPROD > percentToBlock) {
                            MessageService.showMessageByCode("NECECOMP_QTD_MAIOR_PERCENT");
                            
                            widget.currentRow.QTSOLIPROD_inline = oldQTSOLIPROD;
                            
                            return false;
                        }
                    }
                } else if((newQTSOLIPROD < oldQTSOLIPROD) && permissionsArray.DIMINUIR_QUANTIDADE) {
                    if(permissionsArray.percentDiminuir != null && permissionsArray.percentDiminuir != undefined) {
                        percentToBlock = oldQTSOLIPROD - (oldQTSOLIPROD * (parseFloat(permissionsArray.percentDiminuir) / 100));
                        
                        if(newQTSOLIPROD < percentToBlock) {
                            MessageService.showMessageByCode("NECECOMP_QTD_MENOR_PERCENT");
                            
                            widget.currentRow.QTSOLIPROD_inline = oldQTSOLIPROD;
                            
                            return false;
                        }
                    }
                } else if(newQTSOLIPROD == oldQTSOLIPROD) {
                    return true;
                } else {
                    MessageService.showMessageByCode("WITHOUT_PERMISSION");
                    
                    widget.currentRow.QTSOLIPROD_inline = oldQTSOLIPROD;
                    
                    return false;
                }
    		} else {
    			MessageService.showMessageByCode("WITHOUT_PERMISSION");
    			
                widget.currentRow.QTSOLIPROD_inline = oldQTSOLIPROD;
                
                return false;
    		}
    	}
    };
    
    this.showJustificativaDialog = function(args) {
    	if(paramsParaSupri.IDAUDALTSOL == 'S')
    		MessageService.showMessageByCode("INFORM_JUST_CHANGE");
    };
    
    this.mudaJustificativa = function(widget) {
        widget.currentRow.DSJUSTOPER = "";
        if(widget.currentRow.TIPOJUST == "P") {
            widget.getField("DSJUSTOPER").template = "zh-select-autocomplete#field/select-autocomplete.html";
            widget.reload().then(() => {
            	widget.activate();
            });
        } else {
            widget.getField("DSJUSTOPER").template = "field/text-edit.html";
            widget.reload().then(() => {
            	widget.activate();
            });
        }
    };
    
    this.verifyInlineEditQuantidade = function(widget) {
    	const row = widget.currentRow;
    	
    	if((row.IDTIPLAN === 'A' || row.IDTIPLAN === 'C') && paramsParaSupri.IDBLOQALTSOLAUT === 'S') {
    		var percentToBlock;
    		var newQTSOLIPROD;
    		
    		if(widget.currentRow.QTSOLIPROD_inline && (typeof widget.currentRow.QTSOLIPROD_inline == "string"))
            	newQTSOLIPROD = widget.currentRow.QTSOLIPROD_inline.replaceAll('.', '').replaceAll(',', '.');
            else
            	newQTSOLIPROD = widget.currentRow.QTSOLIPROD.replaceAll('.', '').replaceAll(',', '.');
            	
            var oldQTSOLIPROD = widget.currentRow.QTSOLIORIG.replaceAll('.', '').replaceAll(',', '.');
            
            newQTSOLIPROD = parseFloat(newQTSOLIPROD);
            oldQTSOLIPROD = parseFloat(oldQTSOLIPROD);
            
            if(oldQTSOLIPROD == 0) {
            	oldQTSOLIPROD = widget.currentRow.QTSOLIPRODBKP.replaceAll('.', '').replaceAll(',', '.');
            	oldQTSOLIPROD = parseFloat(oldQTSOLIPROD);
            }
            
            if(newQTSOLIPROD == 0 && permissionsArray.EXCLUIR_PRODUTO) {
            	return;
            } else if(permissionsArray.AUMENTAR_QUANTIDADE || permissionsArray.DIMINUIR_QUANTIDADE) {
    			if((newQTSOLIPROD > oldQTSOLIPROD) && permissionsArray.AUMENTAR_QUANTIDADE) {
                    if(permissionsArray.percentAumentar != null && permissionsArray.percentAumentar != undefined) {
                        percentToBlock = oldQTSOLIPROD + (oldQTSOLIPROD * (parseFloat(permissionsArray.percentAumentar) / 100));
                        
                        if(newQTSOLIPROD > percentToBlock) {
                            MessageService.showMessageByCode("NECECOMP_QTD_MAIOR_PERCENT");
                            
                            widget.currentRow.QTSOLIPROD_inline = oldQTSOLIPROD;
                        }
                    }
                } else if((newQTSOLIPROD < oldQTSOLIPROD) && permissionsArray.DIMINUIR_QUANTIDADE) {
                    if(permissionsArray.percentDiminuir != null && permissionsArray.percentDiminuir != undefined) {
                        percentToBlock = oldQTSOLIPROD - (oldQTSOLIPROD * (parseFloat(permissionsArray.percentDiminuir) / 100));
                        
                        if(newQTSOLIPROD < percentToBlock) {
                            MessageService.showMessageByCode("NECECOMP_QTD_MENOR_PERCENT");
                            
                            widget.currentRow.QTSOLIPROD_inline = oldQTSOLIPROD;
                        }
                    }
                } else if(newQTSOLIPROD == oldQTSOLIPROD) {
                    return;
                } else {
                    MessageService.showMessageByCode("WITHOUT_PERMISSION");
                    
                    widget.currentRow.QTSOLIPROD_inline = oldQTSOLIPROD;
                }
    		} else {
    			MessageService.showMessageByCode("WITHOUT_PERMISSION");
    			
                widget.currentRow.QTSOLIPROD_inline = oldQTSOLIPROD;
    		}
    	}
    };
    
    this.saveInlineEdit = function(widget) {
    	const popupJustificativaAlteracao = templateManager.container.getWidget("popupJustificativaAlteracao");
    	
    	if(paramsParaSupri.IDAUDALTSOL == 'S') {
			popupJustificativaAlteracao.getField("TIPOJUST").isVisible = true;
			popupJustificativaAlteracao.getField("DSJUSTOPER").isVisible = true;
			
			popupJustificativaAlteracao.currentRow.TIPOJUST = 'P';
			popupJustificativaAlteracao.currentRow.DSJUSTOPER = '';
			
			popupJustificativaAlteracao.getField("DSJUSTOPER").template = "zh-select-autocomplete#field/select-autocomplete.html";
			
			popupJustificativaAlteracao.getField("DSJUSTOPER").reload().then(() => {
    			ScreenService.openPopup(popupJustificativaAlteracao);
			});
		} else {
			let rows = widget.dataSource.data.filter(row => {
				return row.changed;
			});
	    	let params = [];
	    	
	    	rows.forEach(function(row) {
	    		params.push({
	    			'IDAUDALTSOL'   : paramsParaSupri.IDAUDALTSOL,
					'IDTIPLAN'      : row.IDTIPLAN,
					'IDUTAPROVSOL'  : row.IDUTAPROVSOL,
					'IDPERALTSAPR'  : row.IDPERALTSAPR,
					'IDSOLIAPROV'   : row.IDSOLIAPROV,
					'NRSEQUCONSOL'  : row.NRSEQUCONSOL,
					'QTSOLIPROD'    : row.QTSOLIPROD,
					'QTSOLIORIG'    : row.changed_QTSOLIPROD,
					'CDMARCA'       : row.CDMARCA ? row.CDMARCA : null,
					'CDFILSOLI'     : row.CDFILSOLI,
					'CDFILLAN'      : row.CDFILLAN,
					'NRSOLICMP'     : row.NRSOLICMP,
					'CDPRODUTO'     : row.CDARVPROD,
					'DTPROGENTR'    : row.DTPROGENTR,
					'STATUS'        : row.STATUS,
					'DSJUSTOPER'    : "Alteração Automática",
					'CDOPERADOR'    : getLocalVar('CDOPERADOR'),
					'CDMARCA_OLD'   : row.CDMARCA ? row.CDMARCA : null,
					'CDOPERADOR_OLD': getLocalVar('CDOPERADOR'),
					'CDFILSOLI_OLD' : row.CDFILSOLI,
					'CDFILLAN_OLD'  : row.CDFILLAN,
					'NRSOLICMP_OLD' : row.NRSOLICMP,
					'CDPRODUTO_OLD' : row.CDPRODUTO,
					'DTPROGENTR_OLD': row.DTPROGENTR,
					'QTSOLIPROD_OLD': row.changed_QTSOLIPROD ? row.changed_QTSOLIPROD : row.QTSOLIPROD,
					'STATUS_OLD'    : row.STATUS
	    		});
	    	});
	    	
	    	General.callRestEngine('cmp_solicitacao_solicitacaoCompras#/salvar_alteracoes_solicitacao', 'Row', params).then(function(success) {
	    		MessageService.showMessageByCode("SALVO_SUCESSO");
	    		
	    		widget.commitInlineEdit();
                widget.list();
        		widget.showCheckbox = true;
            	widget.activate();
	    	}.bind(this), function(err) {
			    ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
	    	});
		}
    };
    
    this.cancelaPopupJust = function(widget) {
    	const popupJustificativaAlteracao = templateManager.container.getWidget("popupJustificativaAlteracao");
    	const widgetGrid = templateManager.container.getWidget('cmp06900_alteracao_automatica_solicitacao_compras_grid');
    	
    	ScreenService.closePopup(popupJustificativaAlteracao);
    	
    	widgetGrid.rollbackInlineEdit();
        widgetGrid.list();
    };
    
    this.saveJust = function(widget) {
    	const widgetGrid = templateManager.container.getWidget('cmp06900_alteracao_automatica_solicitacao_compras_grid');
    	const changedRows = widgetGrid.dataSource.data.filter(row => {
    		return row.changed;	
    	});
    	
    	if(changedRows.length > 0) {
    		const confirmaJustificativaAlteracao = templateManager.container.getWidget("popupConfirmaJustificativaAlteracao");
    		const popupJustificativaAlteracao = templateManager.container.getWidget("popupJustificativaAlteracao");
    		
    		changedRows.map(val => {
    			val.DSJUSTOPER = popupJustificativaAlteracao.currentRow.DSJUSTOPER;
    		});
    		
            confirmaJustificativaAlteracao.dataSource.data = changedRows;
            confirmaJustificativaAlteracao.reload().then(() => {
            	ScreenService.openPopup(confirmaJustificativaAlteracao);
            });
    	} else {
    		self.cancelaPopupJust(widget);
        }
    };
    
    this.cancelaPopupConfirmJust = function(widget) {
    	ScreenService.closePopup(widget);
    	
    	widget.dataSource.data = [];
    	
    	self.cancelaPopupJust(widget);
    };
    
    this.salvaConfirmacaoJustificativa = function(widget) {
    	const justificativaRow = widget.dataSource.data.filter(row => row.DSJUSTOPER.length == 0 || !row.DSJUSTOPER);
    	const widgetGrid = templateManager.container.getWidget('cmp06900_alteracao_automatica_solicitacao_compras_grid');
    	const confirmaJustificativaAlteracao = templateManager.container.getWidget("popupConfirmaJustificativaAlteracao");
    	const popupJustificativaAlteracao = templateManager.container.getWidget("popupJustificativaAlteracao");
        
        if(justificativaRow.length == 0) {
        	let rows = widget.dataSource.data;
	    	let params = [];
	    	
	    	rows.forEach(function(row) {
	    		params.push({
	    			'IDAUDALTSOL'   : paramsParaSupri.IDAUDALTSOL,
					'IDTIPLAN'      : row.IDTIPLAN,
					'IDUTAPROVSOL'  : row.IDUTAPROVSOL,
					'IDPERALTSAPR'  : row.IDPERALTSAPR,
					'IDSOLIAPROV'   : row.IDSOLIAPROV,
					'NRSEQUCONSOL'  : row.NRSEQUCONSOL,
					'QTSOLIPROD'    : row.QTSOLIPROD,
					'QTSOLIORIG'    : row.changed_QTSOLIPROD,
					'CDMARCA'       : row.CDMARCA ? row.CDMARCA : null,
					'CDFILSOLI'     : row.CDFILSOLI,
					'CDFILLAN'      : row.CDFILLAN,
					'NRSOLICMP'     : row.NRSOLICMP,
					'CDPRODUTO'     : row.CDARVPROD,
					'DTPROGENTR'    : row.DTPROGENTR,
					'STATUS'        : row.STATUS,
					'DSJUSTOPER'    : row.DSJUSTOPER,
					'CDOPERADOR'    : getLocalVar('CDOPERADOR'),
					'CDMARCA_OLD'   : row.CDMARCA ? row.CDMARCA : null,
					'CDOPERADOR_OLD': getLocalVar('CDOPERADOR'),
					'CDFILSOLI_OLD' : row.CDFILSOLI,
					'CDFILLAN_OLD'  : row.CDFILLAN,
					'NRSOLICMP_OLD' : row.NRSOLICMP,
					'CDPRODUTO_OLD' : row.CDPRODUTO,
					'DTPROGENTR_OLD': row.DTPROGENTR,
					'QTSOLIPROD_OLD': row.changed_QTSOLIPROD ? row.changed_QTSOLIPROD : row.QTSOLIPROD,
					'STATUS_OLD'    : row.STATUS
	    		});
	    	});
	    	
	    	General.callRestEngine('cmp_solicitacao_solicitacaoCompras#/salvar_alteracoes_solicitacao', 'Row', params).then(function(success) {
	    		MessageService.showMessageByCode("SALVO_SUCESSO");
	    		
	    		ScreenService.closePopup(confirmaJustificativaAlteracao);
                ScreenService.closePopup(popupJustificativaAlteracao);
                    
                confirmaJustificativaAlteracao.dataSource.data = [];
                    
                widgetGrid.commitInlineEdit();
                widgetGrid.list();
        		widgetGrid.showCheckbox = true;
            	widgetGrid.activate();
			}.bind(this), function(err) {
			    ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
			    
			    ScreenService.closePopup(confirmaJustificativaAlteracao);
                ScreenService.closePopup(popupJustificativaAlteracao);
                    
                confirmaJustificativaAlteracao.dataSource.data = [];
                    
                widgetGrid.rollbackInlineEdit();
                widgetGrid.list();
                widgetGrid.showCheckbox = true;
                widgetGrid.activate();
			});
        } else {
        	MessageService.showMessageByCode("PREENCHER_JUSTIFICATIVA");
        }
    };
};

Configuration(function(ContextRegister) {
    ContextRegister.register('Cmp06900AlteracaoAutomaticaSolicitacaoComprasController', Cmp06900AlteracaoAutomaticaSolicitacaoComprasController);
});